function irb140(block)
%SFUNDSC2_LEVEL2 Level-2 version of sfundsc2.m
%  
%   Copyright 2003-2007 The MathWorks, Inc. 
  
%%
%% The setup method is used to setup the basic attributes of the
%% S-function such as ports, parameters, etc. Do not add any other
%% calls to the main body of the function.  
%%   
setup(block);
  
%endfunction

function setup(block)

  % Register number of ports
  block.NumInputPorts  = 2;
  block.NumOutputPorts = 1;
  
  % Setup port properties to be inherited or dynamic
  block.SetPreCompInpPortInfoToDynamic;
  block.SetPreCompOutPortInfoToDynamic;

  % Override input port properties
  block.InputPort(1).Dimensions  = [12 1];
  block.InputPort(2).Dimensions  = [6 1];
  block.InputPort(1).DirectFeedthrough = false;
  block.InputPort(2).DirectFeedthrough = false;
  
  % Override output port properties
  block.OutputPort(1).Dimensions  = [12 1];
  
  % Register parameters
  block.NumDialogPrms = 0;

  % Register sample times
  block.SampleTimes = [-1 0];
  
  
  %% -----------------------------------------------------------------
  %% Options
  %% -----------------------------------------------------------------
  % Specify if Accelerator should use TLC or call back into 
  % M-file
  block.SetAccelRunOnTLC(false);
  
    
  %% -----------------------------------------------------------------
  %% Register methods
  %% -----------------------------------------------------------------
  block.RegBlockMethod('InitializeConditions', @InitializeConditions);
  block.RegBlockMethod('Outputs', @Outputs);

%endfunction

%% -------------------------------------------------------------------
%% The local functions 
%% -------------------------------------------------------------------

function InitializeConditions(block)
block.InputPort(1).Data(1) = 0;
block.InputPort(1).Data(2) = 0;
block.InputPort(1).Data(3) = 0;
block.InputPort(1).Data(4) = 0;
block.InputPort(1).Data(5) = 0;
block.InputPort(1).Data(6) = 0;
block.InputPort(1).Data(7) = 0;
block.InputPort(1).Data(8) = 0;
block.InputPort(1).Data(9) = 0;
block.InputPort(1).Data(10) = 0;
block.InputPort(1).Data(11) = 0;
block.InputPort(1).Data(12) = 0;

function Outputs(block)

gravityCompensation = 1; %1 if yes, 0 if no
g = 9.81;

%Defining input ports
u1 = block.InputPort(2).Data(1);
u2 = block.InputPort(2).Data(2);
u3 = block.InputPort(2).Data(3);
u4 = block.InputPort(2).Data(4);
u5 = block.InputPort(2).Data(5);
u6 = block.InputPort(2).Data(6);

q1 = block.InputPort(1).Data(1);
Dq1 = block.InputPort(1).Data(2);
q2 = block.InputPort(1).Data(3);
Dq2 = block.InputPort(1).Data(4);
q3 = block.InputPort(1).Data(5);
Dq3 = block.InputPort(1).Data(6);
q4 = block.InputPort(1).Data(7);
Dq4 = block.InputPort(1).Data(8);
q5 = block.InputPort(1).Data(9);
Dq5 = block.InputPort(1).Data(10);
q6 = block.InputPort(1).Data(11);
Dq6 = block.InputPort(1).Data(12);

%Calculating the elements of M,C,g one by one (the expressions are copied from Maple, and state derivatives have been redefined).
m11 = cos((q5 + 2 * pi - 2 * q4 - 2 * q3 - 2 * q2)) * 0.216840434497100888e-18 + cos((-2 * q2 + pi)) * 0.224527199999999994e1 + cos((2 * q4 + 2 * q3 + 2 * q2 + q5)) * 0.216840434497100888e-18 + cos((-2 * q4 + 2 * q3 + 2 * q2 + q5)) * 0.216840434497100888e-18 + sin(-q2 + pi / 0.2e1 - q3) * 0.333200000000000052e0 + 0.6800000000e-4 * cos((2 * q5 + 3 * pi + q4 - 2 * q3 - 2 * q2)) - 0.1700000000e-4 * cos((2 * q5 + pi + 2 * q3 + 2 * q2 - 2 * q4)) + cos((q5 + q4 + 2 * q3 + 2 * q2)) * 0.275499999999999964e-2 + cos((q5 + 2 * pi - q4 - 2 * q3 - 2 * q2)) * (-0.275499999999999964e-2) + sin((q5 + pi - q4 + q3)) * 0.260999999999999991e-2 + cos((q5 + 2 * q2 + 2 * q3 - q4)) * 0.275499999999999964e-2 + cos((pi + 2 * q4 + q5)) * (-0.433680868994201774e-18) - 0.6800000000e-4 * cos((-q4 + 2 * q5 + pi + 2 * q3 + 2 * q2)) + sin((q5 + 2 * pi - q4 - q3 - 2 * q2)) * 0.260999999999999991e-2 + sin((q5 + q4 + q3 + 2 * q2)) * 0.260999999999999991e-2 + cos((q5 + 2 * pi - 2 * q3 - 2 * q2)) * 0.551000000000000101e-2 + sin((q5 + pi + q3)) * 0.521999999999999982e-2 + sin((q5 + pi - q3)) * (-0.521999999999999982e-2) + cos(-q2 + pi / 0.2e1) * 0.192948000000000008e1 + cos((-2 * q2 + pi + 2 * q4)) * 0.138777878078144570e-16 + sin(q3) * (-0.856800000000000006e0) - 0.1700000000e-4 * cos((2 * q5 + 3 * pi - 2 * q3 - 2 * q2 + 2 * q4)) + 0.3400000000e-4 * cos((2 * q4 + 2 * pi + 2 * q5)) + cos((2 * q4 - 2 * q3 - 2 * q2 + pi)) * 0.340000000000062474e-4 + cos((q5 + 2 * pi + 2 * q4 - 2 * q3 - 2 * q2)) * 0.216840434497100888e-18 + sin((-q3 - 2 * q2 + pi)) * 0.856800000000000006e0 - 0.6800000000e-4 * cos((q4 + 2 * q5 + pi + 2 * q3 + 2 * q2)) + cos((q5 + pi)) * (-0.110200000000000020e-1) + cos((q5 + 2 * q2 + 2 * q3)) * 0.551000000000000101e-2 + sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * (-0.203000000000000012e-2) + sin((q5 + pi + q4 - q3)) * 0.260999999999999991e-2 + sin((q5 + pi + q4 + q3)) * 0.260999999999999991e-2 + sin((q5 + pi - q4 - q3)) * 0.260999999999999991e-2 + cos((pi - 2 * q4 + q5)) * (-0.433680868994201774e-18) - 0.1700000000e-4 * cos((2 * q5 + 3 * pi - 2 * q4 - 2 * q3 - 2 * q2)) + 0.6800000000e-4 * cos((2 * q5 + 3 * pi - q4 - 2 * q3 - 2 * q2)) + sin((q5 + 2 * pi + q4 - q3 - 2 * q2)) * 0.260999999999999991e-2 + sin((q5 - q4 + q3 + 2 * q2)) * 0.260999999999999991e-2 - 0.6800000000e-4 * cos((2 * pi + 2 * q5)) + cos((-2 * q2 + pi - 2 * q3)) * (-0.499655500000000030e0) + 0.3400000000e-4 * cos((-2 * q4 + 2 * pi + 2 * q5)) - 0.1020000000e-3 * cos((2 * q5 + 3 * pi - 2 * q3 - 2 * q2)) - 0.1020000000e-3 * cos((2 * q5 + pi + 2 * q3 + 2 * q2)) + sin(q5 + pi / 0.2e1 + q3 + q2) * 0.203000000000000012e-2 + cos((q5 + 2 * pi - 2 * q2 - 2 * q3 + q4)) * (-0.275499999999999964e-2) - 0.1700000000e-4 * cos((2 * q5 + pi + 2 * q4 + 2 * q3 + 2 * q2)) + cos((2 * q4)) * (-0.679999999999847394e-4) + cos((-2 * q4 - 2 * q3 - 2 * q2 + pi)) * 0.340000000000062474e-4 + sin((q5 + 2 * pi - q3 - 2 * q2)) * (-0.521999999999999982e-2) + sin((q5 + q3 + 2 * q2)) * 0.521999999999999982e-2 + 0.374662799999999940e1 + sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.101500000000000006e-2 + sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.101500000000000006e-2 + sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.101500000000000006e-2 + sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.101500000000000006e-2 + cos((-2 * q2 + pi - 2 * q4)) * 0.138777878078144570e-16;
m12 = cos(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.433680868994201774e-18 + cos(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.433680868994201774e-18) + 0.6800000000e-4 * cos(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) - 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + cos(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * (-0.433680868994201774e-18) + 0.2610000000e-2 * sin(q5 + pi / 0.2e1 + q4 + q2) + cos(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * 0.433680868994201774e-18 - 0.2610000000e-2 * sin(q5 + pi / 0.2e1 - q4 + q2) + 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3400000000e-4 * cos((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.2610000000e-2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) + 0.3400000000e-4 * cos(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + cos((2 * q4) - q3 - q2 + pi / 0.2e1) * (-0.680000000000402504e-4) + cos(-q2 + pi / 0.2e1 - (2 * q4) + q3) * (-0.277555756156289136e-16) + 0.3400000000e-4 * cos((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + cos(-(2 * q4) - q3 - q2 + pi / 0.2e1) * 0.680000000000124950e-4 + 0.309540e0 * sin(-q2 + pi / 0.2e1) - 0.2610000000e-2 * sin(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) - 0.6800000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.6800000000e-4 * cos(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) + 0.6800000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.3400000000e-4 * cos(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4);
m13 = 0.6800000000e-4 * cos(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + 0.6800000000e-4 * cos((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.3400000000e-4 * cos(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + cos(q5 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q4 - q3 - q2) * (-0.433680868994201774e-18) - 0.6800000000e-4 * cos((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.6800000000e-4 * cos((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) + 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.3400000000e-4 * cos(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.3400000000e-4 * cos(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + cos(-0.2e1 * q4 - q3 - q2 + pi / 0.2e1) * 0.680000000000124950e-4 + cos(0.2e1 * q4 - q3 - q2 + pi / 0.2e1) * (-0.680000000000124950e-4) + 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3400000000e-4 * cos(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + cos(q5 + pi / 0.2e1 - 0.2e1 * q4 + q3 + q2) * (-0.433680868994201774e-18) + cos(0.3e1 / 0.2e1 * pi - 0.2e1 * q4 - q3 - q2 + q5) * 0.433680868994201774e-18 + cos(pi / 0.2e1 + 0.2e1 * q4 + q3 + q2 + q5) * 0.433680868994201774e-18;
m14 = 0.6800000000e-4 * cos((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + sin(q5 + pi + q4) * (-0.101500000000000006e-2) + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.275500000000000008e-2 + cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.275500000000000008e-2) + 0.1360000000e-3 * cos(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) + 0.1360000000e-3 * cos((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.6800000000e-4 * cos((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) + 0.6800000000e-4 * cos((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.6800000000e-4 * cos(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + sin(q5 + pi - q4) * (-0.101500000000000006e-2) + sin(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.260999999999999991e-2) + sin(q5 + pi / 0.2e1 + q4 + q2) * (-0.260999999999999991e-2) + sin(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * (-0.260999999999999991e-2) + sin(q5 + pi / 0.2e1 - q4 + q2) * (-0.260999999999999991e-2) + cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.275500000000000008e-2) + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.275500000000000008e-2 - 0.1121800000e0 * cos(-q2 + pi / 0.2e1 - q3);
m15 = 0.1001000000e-2 * cos(-q4 - q3 - q2 + pi / 0.2e1) + cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.275500000000000008e-2 + sin(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * 0.260999999999999991e-2 + cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.275500000000000008e-2) + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.275500000000000008e-2 + sin(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.260999999999999991e-2) + sin(q5 + pi / 0.2e1 + q4 + q2) * (-0.260999999999999991e-2) + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.275500000000000008e-2) + sin(q5 + pi / 0.2e1 - q4 + q2) * 0.260999999999999991e-2 + sin(q5 + pi + q4) * (-0.101500000000000006e-2) - 0.1001000000e-2 * cos(q4 - q3 - q2 + pi / 0.2e1) + sin(q5 + pi - q4) * 0.101500000000000006e-2;
m16 = 0.7290000000e-3 * cos(q5 + pi / 0.2e1 + q3 + q2) + 0.7290000000e-3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.3645000000e-3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.3645000000e-3 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3645000000e-3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.3645000000e-3 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4);

m21 = cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.275499999999999964e-2) + sin(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.260999999999999991e-2) + cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.275499999999999964e-2 + sin(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * 0.260999999999999991e-2 + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.275499999999999964e-2 - 0.3400000000e-4 * cos(0.2e1 * q4 + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.309540e0 * sin(-q2 + pi / 0.2e1) + 0.3400000000e-4 * cos(0.2e1 * q4 + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + sin(q5 + pi / 0.2e1 - q4 + q2) * (-0.260999999999999991e-2) + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.275499999999999964e-2) + cos(-0.2e1 * q4 - q3 - q2 + pi / 0.2e1) * 0.680000000000124950e-4 + sin(q5 + pi / 0.2e1 + q4 + q2) * 0.260999999999999991e-2 + 0.3400000000e-4 * cos(-0.2e1 * q4 + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + cos(0.2e1 * q4 - q3 - q2 + pi / 0.2e1) * (-0.680000000000124950e-4) - 0.6800000000e-4 * cos(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) + 0.6800000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.6800000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + 0.6800000000e-4 * cos(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) - 0.3400000000e-4 * cos(-0.2e1 * q4 + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + cos(q5 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q4 - q3 - q2) * (-0.433680868994201774e-18) + cos(q5 + pi / 0.2e1 - 0.2e1 * q4 + q3 + q2) * (-0.433680868994201774e-18) + cos(0.3e1 / 0.2e1 * pi - 0.2e1 * q4 - q3 - q2 + q5) * 0.433680868994201774e-18 + cos(pi / 0.2e1 + 0.2e1 * q4 + q3 + q2 + q5) * 0.433680868994201774e-18;
m22 = cos((pi + 2 * q4 + q5)) * 0.867361737988403548e-18 + sin((q5 + pi - q4 - q3)) * 0.521999999999999982e-2 + cos((q5 + pi)) * (-0.220400000000000040e-1) + cos((2 * q4)) * 0.136000000000024992e-3 + sin((q5 + pi + q4 - q3)) * 0.521999999999999982e-2 + cos((pi - 2 * q4 + q5)) * 0.867361737988403548e-18 + 0.573033899999999985e1 + sin((q5 + pi + q4 + q3)) * 0.521999999999999982e-2 + sin(q3) * (-0.171360000000000001e1) + sin((q5 + pi - q3)) * (-0.104399999999999997e-1) - 0.6800000000e-4 * cos((-2 * q4 + 2 * pi + 2 * q5)) + 0.1360000000e-3 * cos((2 * pi + 2 * q5)) - 0.6800000000e-4 * cos((2 * q4 + 2 * pi + 2 * q5)) + sin((q5 + pi + q3)) * 0.104399999999999997e-1 + sin((q5 + pi - q4 + q3)) * 0.521999999999999982e-2;
m23 = sin(q3) * (-0.856799999999999894e0) + cos((pi - 2 * q4 + q5)) * 0.867361737988403548e-18 + sin(q5 + pi - q3) * (-0.521999999999999982e-2) + 0.1360000000e-3 * cos((2 * pi + 2 * q5)) - 0.6800000000e-4 * cos((2 * q4 + 2 * pi + 2 * q5)) + cos((q5 + pi)) * (-0.220400000000000040e-1) + cos((pi + 2 * q4 + q5)) * 0.867361737988403548e-18 + cos((2 * q4)) * 0.135999999999913968e-3 - 0.6800000000e-4 * cos((-2 * q4 + 2 * pi + 2 * q5)) + sin(q5 + pi + q4 - q3) * 0.260999999999999991e-2 + sin(q5 + pi - q4 + q3) * 0.260999999999999991e-2 + sin(q5 + pi - q4 - q3) * 0.260999999999999991e-2 + sin(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + sin(q5 + pi + q3) * 0.521999999999999982e-2 + 0.111149100000000001e1;
m24 = cos(q5 + pi + q4) * (-0.551000000000000014e-2) - 0.1360000000e-3 * cos(0.2e1 * q5 + 0.2e1 * pi - q4) + 0.1360000000e-3 * cos(q4 + 0.2e1 * pi + 0.2e1 * q5) + cos(q5 + pi - q4) * 0.551000000000000014e-2 + sin(q5 + pi - q4 + q3) * (-0.260999999999999991e-2) + sin(q5 + pi - q4 - q3) * 0.260999999999999991e-2 + sin(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + sin(q5 + pi + q4 - q3) * (-0.260999999999999991e-2);
m25 = cos(q5 + pi + q4) * (-0.551000000000000014e-2) + sin(q5 + pi - q4 - q3) * (-0.260999999999999991e-2) + sin(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + sin(q5 + pi + q4 - q3) * (-0.260999999999999991e-2) + 0.2002000000e-2 * cos(q4) + cos(q5 + pi - q4) * (-0.551000000000000014e-2) + sin(q5 + pi + q3) * 0.521999999999999982e-2 + sin(q5 + pi - q3) * 0.521999999999999982e-2 + sin(q5 + pi - q4 + q3) * 0.260999999999999991e-2;
m26 = -0.7290000000e-3 * cos(q5 + pi - q4) + 0.7290000000e-3 * cos(q5 + pi + q4);

m31 = cos((2 * q4) - q3 - q2 + pi / 0.2e1) * (-0.680000000000124950e-4) + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.275499999999999964e-2 + 0.3400000000e-4 * cos(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.275499999999999964e-2) - 0.6800000000e-4 * cos(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) + 0.3400000000e-4 * cos((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.3400000000e-4 * cos((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.6800000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + cos(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.433680868994201774e-18 + cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.275499999999999964e-2 - 0.3400000000e-4 * cos(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + cos(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * 0.433680868994201774e-18 + cos(-(2 * q4) - q3 - q2 + pi / 0.2e1) * 0.679999999999569838e-4 + cos(-q2 + pi / 0.2e1 - q3) * (-0.555111512312578272e-16) + cos(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * (-0.433680868994201774e-18) + cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.275499999999999964e-2) + 0.6800000000e-4 * cos(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) + cos(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.433680868994201774e-18);
m32 = 0.5220000000e-2 * sin(q5 + pi + q3) + 0.2610000000e-2 * sin(q5 + pi - q4 + q3) + sin(q3) * (-0.856800000000000006e0) + 0.2610000000e-2 * sin(q5 + pi - q4 - q3) - 0.5220000000e-2 * sin(q5 + pi - q3) + cos(pi + 0.2e1 * q4 + q5) * 0.867361737988403548e-18 + 0.111149100000000001e1 - 0.6800000000e-4 * cos(0.2e1 * q4 + 0.2e1 * pi + 0.2e1 * q5) + cos(q5 + pi) * (-0.220400000000000040e-1) + 0.2610000000e-2 * sin(q5 + pi + q4 - q3) + cos(0.2e1 * q4) * 0.136000000000024992e-3 + cos(pi - 0.2e1 * q4 + q5) * 0.867361737988403548e-18 - 0.6800000000e-4 * cos(-0.2e1 * q4 + 0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * cos(0.2e1 * pi + 0.2e1 * q5) + 0.2610000000e-2 * sin(q5 + pi + q4 + q3);
m33 = -0.6800000000e-4 * cos((-2 * q4 + 2 * pi + 2 * q5)) + 0.111149100000000001e1 + cos((2 * q4)) * 0.136000000000024992e-3 - 0.6800000000e-4 * cos((2 * q4 + 2 * pi + 2 * q5)) + cos((q5 + pi)) * (-0.220400000000000040e-1) + 0.1360000000e-3 * cos((2 * pi + 2 * q5)) + cos((pi + 2 * q4 + q5)) * 0.867361737988403548e-18 + cos((pi - 2 * q4 + q5)) * 0.867361737988403548e-18;
m34 = cos(q5 + pi + q4) * (-0.551000000000000014e-2) - 0.1360000000e-3 * cos(0.2e1 * q5 + 0.2e1 * pi - q4) + 0.1360000000e-3 * cos(q4 + 0.2e1 * pi + 0.2e1 * q5) + cos(q5 + pi - q4) * 0.551000000000000014e-2;
m35 = 0.2002000000e-2 * cos(q4) + cos(q5 + pi - q4) * (-0.551000000000000014e-2) + cos(q5 + pi + q4) * (-0.551000000000000014e-2);
m36 = -0.7290000000e-3 * cos(q5 + pi - q4) + 0.7290000000e-3 * cos(q5 + pi + q4);

m41 = -0.1015000000e-2 * sin(q5 + pi + q4) + 0.1360000000e-3 * cos(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.2610000000e-2 * sin(q5 + pi / 0.2e1 - q4 + q2) - 0.680000000e-4 * cos(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1015000000e-2 * sin(q5 + pi - q4) - 0.2610000000e-2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) + 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.680000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.2610000000e-2 * sin(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) - 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.1121800000e0 * cos(-q2 + pi / 0.2e1 - q3) - 0.680000000e-4 * cos(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) - 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.680000000e-4 * cos(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.2610000000e-2 * sin(q5 + pi / 0.2e1 + q4 + q2) + 0.1360000000e-3 * cos(q3 + q2 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q5);
m42 = -0.5510000000e-2 * cos(q5 + pi + q4) + 0.5510000000e-2 * cos(q5 + pi - q4) - 0.2610000000e-2 * sin(q5 + pi + q4 - q3) + 0.2610000000e-2 * sin(q5 + pi - q4 - q3) - 0.2610000000e-2 * sin(q5 + pi - q4 + q3) - 0.1360000000e-3 * cos(0.2e1 * q5 + 0.2e1 * pi - q4) + 0.2610000000e-2 * sin(q5 + pi + q4 + q3) + 0.1360000000e-3 * cos(q4 + 0.2e1 * pi + 0.2e1 * q5);
m43 = -0.5510000000e-2 * cos(q5 + pi + q4) - 0.1360000000e-3 * cos(0.2e1 * q5 + 0.2e1 * pi - q4) + 0.5510000000e-2 * cos(q5 + pi - q4) + 0.1360000000e-3 * cos(q4 + 0.2e1 * pi + 0.2e1 * q5);
m44 = -0.2720000000e-3 * cos((2 * pi + 2 * q5)) + 0.1121800000e0;
m45 = 0.0e0;
m46 = -0.1458000000e-2 * cos(q5 + pi);

m51 = -0.2610000000e-2 * sin(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) - 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.2610000000e-2 * sin(q5 + pi / 0.2e1 + q4 + q2) + 0.2610000000e-2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) + 0.2755000000e-2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.1001000000e-2 * cos(q4 - q3 - q2 + pi / 0.2e1) + 0.2755000000e-2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.1015000000e-2 * sin(q5 + pi + q4) + 0.1015000000e-2 * sin(q5 + pi - q4) + 0.1001000000e-2 * cos(-q4 - q3 - q2 + pi / 0.2e1) + 0.2610000000e-2 * sin(q5 + pi / 0.2e1 - q4 + q2);
m52 = 0.2610000000e-2 * sin(q5 + pi + q4 + q3) - 0.2610000000e-2 * sin(q5 + pi + q4 - q3) + 0.5220000000e-2 * sin(q5 + pi - q3) + 0.2002000000e-2 * cos(q4) + 0.2610000000e-2 * sin(q5 + pi - q4 + q3) + 0.5220000000e-2 * sin(q5 + pi + q3) - 0.5510000000e-2 * cos(q5 + pi + q4) - 0.5510000000e-2 * cos(q5 + pi - q4) - 0.2610000000e-2 * sin(q5 + pi - q4 - q3);
m53 = -0.5510000000e-2 * cos(q5 + pi + q4) - 0.5510000000e-2 * cos(q5 + pi - q4) + 0.2002000000e-2 * cos(q4);
m54 = 0.0e0;
m55 = 0.2002000000e-2;
m56 = 0.0e0;

m61 = 0.7290000000e-3 * cos(q5 + pi / 0.2e1 + q3 + q2) + 0.7290000000e-3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.3645000000e-3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.3645000000e-3 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3645000000e-3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.3645000000e-3 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4);
m62 = -0.7290000000e-3 * cos(q5 + pi - q4) + 0.7290000000e-3 * cos(q5 + pi + q4);
m63 = -0.7290000000e-3 * cos(q5 + pi - q4) + 0.7290000000e-3 * cos(q5 + pi + q4);
m64 = -0.1458000000e-2 * cos(q5 + pi);
m65 = 0.0e0;
m66 = 0.1458000000e-2;

g1 = 0;
g2 = 0.1450000000e-1 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.1450000000e-1 * g * sin(q5 + pi / 0.2e1 + q3 + q2) + cos(-q2 + pi / 0.2e1) * g * (-0.137820000000000000e2) - 0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + sin(-q2 + pi / 0.2e1 - q3) * g * (-0.237999999999999988e1);
g3 = -0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + sin(-q2 + pi / 0.2e1 - q3) * g * (-0.237999999999999988e1) - 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.1450000000e-1 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.1450000000e-1 * g * sin(q5 + pi / 0.2e1 + q3 + q2);
g4 = -0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 - q4);
g5 = -0.1450000000e-1 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.1450000000e-1 * g * sin(q5 + pi / 0.2e1 + q3 + q2) - 0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.7250000000e-2 * g * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.7250000000e-2 * g * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4);
g6 = 0.0e0;

cdq1 = Dq1 ^ 2 * sin(q2 + 0.3e1 / 0.2e1 * pi + (3 * q3) - q4 + (2 * q5)) * (-0.128749007982653654e-18) + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + (3 * q3) - q4 + (2 * q5)) * (-0.393023287525995358e-18) + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + (2 * q5) + q3) * 0.440457132572236176e-19 + Dq1 ^ 2 * sin(q2 + 0.3e1 / 0.2e1 * pi + (3 * q3) + (2 * q5) - 0.2e1 * q4) * 0.440457132572236176e-19 + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + (3 * q3) + (2 * q5) - 0.2e1 * q4) * 0.440457132572236176e-19 + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + q3 + (2 * q5) - 0.2e1 * q4) * (-0.440457132572236176e-19) + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + (2 * q5) + q4 + q3) * (-0.128749007982653654e-18) + Dq1 ^ 2 * sin(q2 + 0.3e1 / 0.2e1 * pi + (3 * q3) + q4 + (2 * q5)) * 0.128749007982653654e-18 + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + (3 * q3) + q4 + (2 * q5)) * 0.393023287525995358e-18 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.5e1 / 0.2e1 * pi - (3 * q3) + q5 - q4) * (-0.108420217248550444e-18) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.7e1 / 0.2e1 * pi + (2 * q5) - q3) * 0.303237795117039522e-18 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.3e1 / 0.2e1 * pi - (3 * q3)) * (-0.346944695195361420e-17) + Dq1 ^ 2 * sin(-q2 + pi / 0.2e1 - (3 * q3)) * 0.346944695195361420e-17 + Dq1 ^ 2 * cos(-0.3e1 * q2 + 0.5e1 / 0.2e1 * pi + q5 - (2 * q3) + q4) * (-0.271050543121376109e-19) + Dq1 ^ 2 * sin(q2 + 0.3e1 / 0.2e1 * pi + (3 * q3) + (2 * q5)) * (-0.440457132572236176e-19) + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + (3 * q3) + (2 * q5)) * (-0.440457132572236176e-19) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.3e1 / 0.2e1 * pi - q3) * (-0.346944695195361420e-17) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.7e1 / 0.2e1 * pi - (3 * q3) + (2 * q5)) * (-0.423516473627150169e-19) + Dq1 ^ 2 * sin(-q2 + 0.5e1 / 0.2e1 * pi - (3 * q3) + (2 * q5)) * (-0.303237795117039522e-18) + Dq1 ^ 2 * sin(-0.3e1 * q2 + pi / 0.2e1 - (3 * q3) - 0.2e1 * q4 - q5) * 0.108420217248550444e-18 + Dq1 ^ 2 * cos(q5 + pi + q4) * 0.271050543121376109e-19 + Dq1 ^ 2 * sin(-q2 + pi / 0.2e1 + 0.2e1 * q4 + q3) * (-0.107539302983405972e-16) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.3e1 / 0.2e1 * pi - (3 * q3) - 0.2e1 * q4) * 0.381503639443336873e-17 + Dq1 ^ 2 * sin(-q2 + pi / 0.2e1 - (3 * q3) - 0.2e1 * q4) * 0.693889390390722838e-17 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.3e1 / 0.2e1 * pi - 0.2e1 * q4 - q3) * (-0.123158590530775270e-16) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.7e1 / 0.2e1 * pi - q3 + (2 * q5) - 0.2e1 * q4) * (-0.863973606199386346e-19) + Dq1 ^ 2 * sin(-q2 + 0.5e1 / 0.2e1 * pi - (3 * q3) + (2 * q5) + 0.2e1 * q4) * 0.216840434497100888e-18 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.7e1 / 0.2e1 * pi - q3 + (2 * q5) + 0.2e1 * q4) * (-0.216840434497100888e-18) + Dq1 ^ 2 * sin(-q2 + pi / 0.2e1 - 0.2e1 * q4 + q3) * 0.107539302983405972e-16 + Dq1 ^ 2 * cos(q5 + pi - q4) * (-0.271050543121376109e-19) + Dq1 ^ 2 * sin(-0.3e1 * q2 + pi / 0.2e1 - (3 * q3) - q5 + q4) * (-0.108420217248550444e-18) + Dq1 ^ 2 * cos(-(2 * q3) + q5 + 0.3e1 / 0.2e1 * pi - q2 + q4) * (-0.271050543121376109e-19) + Dq1 ^ 2 * sin(-0.3e1 * q2 + pi / 0.2e1 - (3 * q3) - q5 - q4) * 0.108420217248550444e-18 + Dq1 ^ 2 * sin(-0.3e1 * q2 + pi / 0.2e1 - (3 * q3) + 0.2e1 * q4 - q5) * (-0.108420217248550444e-18) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.5e1 / 0.2e1 * pi - (3 * q3) + q5 + 0.2e1 * q4) * (-0.108420217248550444e-18) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.5e1 / 0.2e1 * pi - (3 * q3) + q5 - 0.2e1 * q4) * 0.108420217248550444e-18 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.3e1 / 0.2e1 * pi - (3 * q3) + 0.2e1 * q4) * (-0.728448334638698292e-17) + Dq1 ^ 2 * sin(-q2 + pi / 0.2e1 - (3 * q3) + 0.2e1 * q4) * (-0.346944695195361420e-17) + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q4 - q3) * 0.884641210112391274e-17 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.5e1 / 0.2e1 * pi - (3 * q3) + q5 + q4) * 0.108420217248550444e-18 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.7e1 / 0.2e1 * pi - (3 * q3) + (2 * q5) - 0.2e1 * q4) * (-0.863973606199386346e-19) + Dq1 ^ 2 * sin(-q2 + 0.5e1 / 0.2e1 * pi - (3 * q3) + (2 * q5) - 0.2e1 * q4) * 0.863973606199386346e-19 + Dq1 ^ 2 * sin(-0.3e1 * q2 + 0.7e1 / 0.2e1 * pi - (3 * q3) + (2 * q5) + 0.2e1 * q4) * 0.128749007982653654e-18 + Dq1 ^ 2 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) * 0.440457132572236176e-19 + Dq1 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) * (-0.474338450462408190e-19) + Dq1 ^ 2 * sin(pi / 0.2e1 + 0.2e1 * q4 + q3 + q2 + q5) * 0.108420217248550444e-18 + Dq1 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q4 - q3 - q2) * 0.108420217248550444e-18 + Dq1 ^ 2 * sin(q5 + pi / 0.2e1 - 0.2e1 * q4 + q3 + q2) * (-0.108420217248550444e-18) + Dq1 * Dq3 * sin((2 * q5) + pi + 0.2e1 * q4 + (2 * q3) + 0.2e1 * q2) * 0.340000000000006908e-4 + 0.1360000000e-3 * Dq1 * Dq3 * sin(-q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + Dq1 * Dq3 * sin((2 * q5) + 0.3e1 * pi - (2 * q3) - 0.2e1 * q2 + 0.2e1 * q4) * (-0.340000000000006908e-4) + 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.3e1 * pi + q4 - (2 * q3) - 0.2e1 * q2) + 0.1360000000e-3 * Dq1 * Dq3 * sin(q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.3e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) + Dq1 * Dq3 * sin((2 * q5) + 0.3e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * (-0.340000000000006908e-4) + Dq1 * Dq3 * cos(q5 - q4 + q3 + 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq3 * cos(q5 + 0.2e1 * pi + q4 - q3 - 0.2e1 * q2) * (-0.260999999999999991e-2) + Dq1 * Dq3 * sin(q5 + 0.2e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) * (-0.551000000000000014e-2) + Dq1 * Dq3 * sin(q5 + q4 + (2 * q3) + 0.2e1 * q2) * (-0.551000000000000014e-2) + Dq1 * Dq3 * sin(q5 + 0.2e1 * pi - 0.2e1 * q2 - (2 * q3) + q4) * (-0.551000000000000014e-2) + Dq1 * Dq3 * sin(q5 + 0.2e1 * q2 + (2 * q3) - q4) * (-0.551000000000000014e-2) + Dq1 * Dq3 * cos(q5 + q4 + q3 + 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq3 * cos(q5 + 0.2e1 * pi - q4 - q3 - 0.2e1 * q2) * (-0.260999999999999991e-2) + 0.6800000000e-4 * Dq1 * Dq3 * sin(0.2e1 * q4 - (2 * q3) - 0.2e1 * q2 + pi) + Dq1 * Dq3 * sin(0.2e1 * pi + (2 * q5)) * (-0.352365706057788941e-18) + Dq1 * Dq4 * sin(pi + 0.2e1 * q4 + q5) * (-0.216840434497100888e-18) + Dq1 * Dq4 * sin(pi - 0.2e1 * q4 + q5) * 0.216840434497100888e-18 + Dq1 * Dq4 * sin(q5 + 0.2e1 * pi + 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * 0.108420217248550444e-18 + Dq1 * Dq4 * sin(0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * 0.108420217248550444e-18 + Dq1 * Dq4 * sin(-0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * (-0.108420217248550444e-18) + Dq1 * Dq4 * sin(q5 + 0.2e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * (-0.108420217248550444e-18) + 0.6800000000e-4 * Dq1 * Dq4 * sin(-0.2e1 * q4 - (2 * q3) - 0.2e1 * q2 + pi) - 0.3400000000e-4 * Dq1 * Dq4 * sin((2 * q5) + pi + (2 * q3) + 0.2e1 * q2 - 0.2e1 * q4) + 0.3400000000e-4 * Dq1 * Dq4 * sin((2 * q5) + pi + 0.2e1 * q4 + (2 * q3) + 0.2e1 * q2) - 0.6800000000e-4 * Dq1 * Dq4 * sin(-q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + 0.3400000000e-4 * Dq1 * Dq4 * sin((2 * q5) + 0.3e1 * pi - (2 * q3) - 0.2e1 * q2 + 0.2e1 * q4) - 0.6800000000e-4 * Dq1 * Dq4 * sin((2 * q5) + 0.3e1 * pi + q4 - (2 * q3) - 0.2e1 * q2) + 0.6800000000e-4 * Dq1 * Dq4 * sin(q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + 0.7290000000e-3 * Dq3 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.7290000000e-3 * Dq3 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2) - 0.1121800000e0 * Dq3 * Dq4 * sin(-q2 + pi / 0.2e1 - q3) + 0.1360000000e-3 * Dq3 * Dq4 * sin(-0.2e1 * q4 - q3 - q2 + pi / 0.2e1) + 0.1360000000e-3 * Dq3 * Dq4 * sin(0.2e1 * q4 - q3 - q2 + pi / 0.2e1) + 0.6800000000e-4 * Dq3 * Dq4 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) - 0.1360000000e-3 * Dq3 * Dq4 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq3 * Dq4 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.6800000000e-4 * Dq3 * Dq4 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.1360000000e-3 * Dq3 * Dq4 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.6800000000e-4 * Dq3 * Dq5 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.6800000000e-4 * Dq3 * Dq5 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq3 * Dq5 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq3 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q4 - q3 - q2) * 0.433680868994201774e-18 + 0.6800000000e-4 * Dq3 * Dq5 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.1001000000e-2 * Dq3 * Dq5 * sin(-q4 - q3 - q2 + pi / 0.2e1) + 0.1360000000e-3 * Dq3 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.1360000000e-3 * Dq3 * Dq5 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + 0.1360000000e-3 * Dq3 * Dq5 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq3 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.1001000000e-2 * Dq3 * Dq5 * sin(q4 - q3 - q2 + pi / 0.2e1) - 0.3645000000e-3 * Dq3 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3645000000e-3 * Dq3 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.3645000000e-3 * Dq3 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.3645000000e-3 * Dq3 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.6800000000e-4 * Dq3 * Dq4 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.2720000000e-3 * Dq4 * Dq5 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) + Dq4 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.551000000000000014e-2) + 0.1360000000e-3 * Dq4 * Dq5 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + Dq4 * Dq5 * cos(q5 + pi - q4) * (-0.203000000000000012e-2) - 0.2720000000e-3 * Dq4 * Dq5 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq4 * Dq5 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * (-0.521999999999999982e-2) + Dq4 * Dq5 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.551000000000000014e-2 + 0.1001000000e-2 * Dq4 * Dq5 * sin(q4 - q3 - q2 + pi / 0.2e1) - 0.1360000000e-3 * Dq4 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.1001000000e-2 * Dq4 * Dq5 * sin(-q4 - q3 - q2 + pi / 0.2e1) + Dq4 * Dq5 * cos(q5 + pi / 0.2e1 + q4 + q2) * (-0.521999999999999982e-2) + Dq4 * Dq5 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.521999999999999982e-2) + Dq4 * Dq5 * cos(q5 + pi / 0.2e1 - q4 + q2) * (-0.521999999999999982e-2) + 0.1360000000e-3 * Dq4 * Dq5 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq4 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + Dq4 * Dq5 * cos(q5 + pi + q4) * (-0.203000000000000012e-2) + Dq4 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.551000000000000014e-2) + Dq4 * Dq5 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.551000000000000014e-2 + 0.3645000000e-3 * Dq4 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.3645000000e-3 * Dq4 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.3645000000e-3 * Dq4 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.3645000000e-3 * Dq4 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.7290000000e-3 * Dq6 * Dq5 * sin(q5 + pi / 0.2e1 + q3 + q2) - 0.3645000000e-3 * Dq6 * Dq5 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.3645000000e-3 * Dq6 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3645000000e-3 * Dq6 * Dq5 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.3645000000e-3 * Dq6 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.7290000000e-3 * Dq6 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) + 0.6800000000e-4 * Dq1 * Dq4 * sin((2 * q5) + 0.3e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) - 0.3400000000e-4 * Dq1 * Dq4 * sin((2 * q5) + 0.3e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) + Dq1 * Dq4 * cos(q5 - q4 + q3 + 0.2e1 * q2) * (-0.260999999999999991e-2) + Dq1 * Dq4 * cos(q5 + 0.2e1 * pi + q4 - q3 - 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq4 * sin(q5 + 0.2e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) * (-0.275500000000000008e-2) + Dq1 * Dq4 * sin(q5 + q4 + (2 * q3) + 0.2e1 * q2) * (-0.275500000000000008e-2) + Dq1 * Dq4 * sin(q5 + 0.2e1 * pi - 0.2e1 * q2 - (2 * q3) + q4) * 0.275500000000000008e-2 + Dq1 * Dq4 * sin(q5 + 0.2e1 * q2 + (2 * q3) - q4) * 0.275500000000000008e-2 + Dq1 * Dq4 * cos(q5 + q4 + q3 + 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq4 * cos(q5 + 0.2e1 * pi - q4 - q3 - 0.2e1 * q2) * (-0.260999999999999991e-2) - 0.6800000000e-4 * Dq1 * Dq4 * sin(0.2e1 * q4 - (2 * q3) - 0.2e1 * q2 + pi) + Dq1 * Dq5 * sin(q5 + 0.2e1 * pi + 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * 0.216840434497100888e-18 + Dq1 * Dq5 * sin(q5 + 0.2e1 * pi - (2 * q3) - 0.2e1 * q2) * (-0.550999999999999928e-2) + Dq1 * Dq5 * sin(q5 + 0.2e1 * q2 + (2 * q3)) * (-0.550999999999999928e-2) + Dq1 * Dq5 * cos(q5 + q3 + 0.2e1 * q2) * 0.521999999999999982e-2 + Dq1 * Dq5 * cos(q5 + 0.2e1 * pi - q3 - 0.2e1 * q2) * (-0.521999999999999982e-2) + Dq1 * Dq5 * sin(0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * 0.216840434497100888e-18 + 0.2040000000e-3 * Dq1 * Dq5 * sin((2 * q5) + 0.3e1 * pi - (2 * q3) - 0.2e1 * q2) + Dq1 * Dq5 * sin(-0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * 0.216840434497100888e-18 + 0.2040000000e-3 * Dq1 * Dq5 * sin((2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + Dq1 * Dq5 * sin(q5 + 0.2e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * 0.216840434497100888e-18 + 0.3400000000e-4 * Dq1 * Dq5 * sin((2 * q5) + pi + (2 * q3) + 0.2e1 * q2 - 0.2e1 * q4) + 0.3400000000e-4 * Dq1 * Dq5 * sin((2 * q5) + pi + 0.2e1 * q4 + (2 * q3) + 0.2e1 * q2) + 0.1360000000e-3 * Dq1 * Dq5 * sin(-q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + 0.3400000000e-4 * Dq1 * Dq5 * sin((2 * q5) + 0.3e1 * pi - (2 * q3) - 0.2e1 * q2 + 0.2e1 * q4) - 0.1360000000e-3 * Dq1 * Dq5 * sin((2 * q5) + 0.3e1 * pi + q4 - (2 * q3) - 0.2e1 * q2) + 0.1360000000e-3 * Dq1 * Dq5 * sin(q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) - 0.1360000000e-3 * Dq1 * Dq5 * sin((2 * q5) + 0.3e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) + 0.3400000000e-4 * Dq1 * Dq5 * sin((2 * q5) + 0.3e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) + Dq1 * Dq3 * cos(q5 + pi + q3) * 0.521999999999999982e-2 + Dq1 * Dq3 * cos(q5 + pi + q4 - q3) * (-0.260999999999999991e-2) + Dq1 * Dq3 * cos(q3) * (-0.856799999999999894e0) + Dq1 * Dq3 * cos(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + Dq1 * Dq3 * cos(q5 + pi - q4 - q3) * (-0.260999999999999991e-2) + Dq1 * Dq3 * cos(q5 + pi - q4 + q3) * 0.260999999999999991e-2 + Dq1 * Dq3 * cos(q5 + pi - q3) * 0.521999999999999982e-2 + sin(-q2 + pi / 0.2e1) * Dq1 * Dq2 * 0.192948000000000008e1 + 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q4) - 0.6800000000e-4 * Dq1 * Dq4 * sin(0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) + 0.6800000000e-4 * Dq1 * Dq4 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) + 0.1360000000e-3 * Dq1 * Dq5 * sin(0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq1 * Dq5 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq1 * Dq5 * sin(0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) + Dq1 * Dq5 * sin(pi + 0.2e1 * q4 + q5) * (-0.433680868994201774e-18) + Dq1 * Dq5 * sin(q5 + pi) * 0.110199999999999986e-1 + Dq1 * Dq5 * sin(pi - 0.2e1 * q4 + q5) * (-0.433680868994201774e-18) + Dq1 * Dq3 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) * 0.345589442479754540e-18 + Dq1 * Dq3 * sin(0.2e1 * q4) * (-0.277555756156289136e-16) + Dq1 * Dq5 * cos(q5 - q4 + q3 + 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq5 * cos(q5 + 0.2e1 * pi + q4 - q3 - 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq5 * sin(q5 + 0.2e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) * 0.275500000000000008e-2 + Dq1 * Dq5 * sin(q5 + q4 + (2 * q3) + 0.2e1 * q2) * (-0.275500000000000008e-2) + Dq1 * Dq5 * sin(q5 + 0.2e1 * pi - 0.2e1 * q2 - (2 * q3) + q4) * 0.275500000000000008e-2 + Dq1 * Dq5 * sin(q5 + 0.2e1 * q2 + (2 * q3) - q4) * (-0.275500000000000008e-2) + Dq1 * Dq5 * cos(q5 + q4 + q3 + 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq5 * cos(q5 + 0.2e1 * pi - q4 - q3 - 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq2 * sin(0.2e1 * q2 + pi - 0.2e1 * q4 + (2 * q5)) * (-0.172794721239877270e-18) + Dq1 * Dq2 * sin(0.2e1 * pi + (2 * q3) - 0.2e1 * q4 + (2 * q5)) * 0.172794721239877270e-18 + Dq1 * Dq2 * sin(-0.2e1 * q2 + 0.2e1 * pi - 0.2e1 * q4 + q5) * (-0.216840434497100888e-18) + Dq1 * Dq2 * sin(0.2e1 * q2 + q5) * (-0.867361737988403548e-18) + Dq1 * Dq2 * sin(pi + (2 * q3) + q5) * 0.867361737988403548e-18 + Dq1 * Dq2 * sin(0.2e1 * q2 + pi + (2 * q5)) * 0.176182853028894472e-18 + Dq1 * Dq2 * sin(0.2e1 * pi + (2 * q3) + (2 * q5)) * (-0.176182853028894472e-18) + Dq1 * Dq2 * sin((2 * q3) + 0.2e1 * q4) * 0.277555756156289136e-16 + Dq1 * Dq2 * sin(-0.2e1 * q2 + pi + 0.2e1 * q4) * (-0.277555756156289136e-16) + Dq1 * Dq2 * sin((2 * q5) + pi + (2 * q3) + 0.2e1 * q2 - 0.2e1 * q4) * 0.340000000000005146e-4 + Dq1 * Dq2 * sin((2 * q5) + pi + 0.2e1 * q4 + (2 * q3) + 0.2e1 * q2) * 0.340000000000006908e-4 + 0.1360000000e-3 * Dq1 * Dq2 * sin(-q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + Dq1 * Dq2 * sin((2 * q5) + 0.3e1 * pi - (2 * q3) - 0.2e1 * q2 + 0.2e1 * q4) * (-0.340000000000005146e-4) + 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.3e1 * pi + q4 - (2 * q3) - 0.2e1 * q2) + 0.1360000000e-3 * Dq1 * Dq2 * sin(q4 + (2 * q5) + pi + (2 * q3) + 0.2e1 * q2) + 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.3e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) + Dq1 * Dq2 * sin((2 * q5) + 0.3e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * (-0.340000000000001758e-4) + Dq1 * Dq2 * cos(q5 - q4 + q3 + 0.2e1 * q2) * 0.521999999999999982e-2 + Dq1 * Dq2 * cos(q5 + 0.2e1 * pi + q4 - q3 - 0.2e1 * q2) * (-0.521999999999999982e-2) + Dq1 * Dq2 * sin(q5 + 0.2e1 * pi - q4 - (2 * q3) - 0.2e1 * q2) * (-0.551000000000000014e-2) + Dq1 * Dq2 * sin(q5 + q4 + (2 * q3) + 0.2e1 * q2) * (-0.551000000000000014e-2) + Dq1 * Dq2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q2 - (2 * q3) + q4) * (-0.551000000000000014e-2) + Dq1 * Dq2 * sin(q5 + 0.2e1 * q2 + (2 * q3) - q4) * (-0.551000000000000014e-2) + Dq1 * Dq2 * cos(q5 + q4 + q3 + 0.2e1 * q2) * 0.521999999999999982e-2 + Dq1 * Dq2 * cos(q5 + 0.2e1 * pi - q4 - q3 - 0.2e1 * q2) * (-0.521999999999999982e-2) + Dq1 * Dq2 * sin(0.2e1 * q4 - (2 * q3) - 0.2e1 * q2 + pi) * 0.679999999999444884e-4 + Dq1 * Dq2 * cos(q5 + pi + q4 - q3) * (-0.433680868994201774e-18) + Dq1 * Dq2 * sin(0.2e1 * pi + (2 * q5)) * 0.501443504774545801e-18 + Dq1 * Dq2 * sin(0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) * (-0.172794721239877270e-18) + Dq1 * Dq3 * sin(q5 + 0.2e1 * pi + 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * 0.433680868994201774e-18 + Dq1 * Dq3 * cos(-q3 - 0.2e1 * q2 + pi) * (-0.856799999999999894e0) + Dq1 * Dq3 * sin(q5 + 0.2e1 * pi - (2 * q3) - 0.2e1 * q2) * 0.110200000000000020e-1 + Dq1 * Dq3 * sin(q5 + 0.2e1 * q2 + (2 * q3)) * (-0.110200000000000020e-1) + Dq1 * Dq3 * cos(q5 + q3 + 0.2e1 * q2) * 0.521999999999999982e-2 + Dq1 * Dq3 * cos(q5 + 0.2e1 * pi - q3 - 0.2e1 * q2) * 0.521999999999999982e-2 + Dq1 * Dq3 * sin(0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * (-0.433680868994201774e-18) + Dq1 * Dq3 * sin(-0.2e1 * q2 + pi - (2 * q3)) * (-0.999310999999999948e0) + Dq1 * Dq3 * sin((2 * q5) + 0.3e1 * pi - (2 * q3) - 0.2e1 * q2) * (-0.203999999999998616e-3) + Dq1 * Dq3 * sin(-0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * (-0.433680868994201774e-18) + Dq1 * Dq3 * sin((2 * q5) + pi + (2 * q3) + 0.2e1 * q2) * 0.203999999999998969e-3 + Dq1 * Dq3 * sin(q5 + 0.2e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * 0.433680868994201774e-18 + Dq1 * Dq3 * sin(-0.2e1 * q2 + pi) * 0.111022302462515654e-15 + Dq1 * Dq3 * sin(-0.2e1 * q4 - (2 * q3) - 0.2e1 * q2 + pi) * 0.679999999999722440e-4 + Dq1 * Dq3 * sin((2 * q3)) * 0.111022302462515654e-15 + Dq1 * Dq3 * sin(-0.2e1 * q2 + pi - 0.2e1 * q4) * (-0.277555756156289136e-16) + Dq1 * Dq3 * sin((2 * q3) + 0.2e1 * q4) * (-0.277555756156289136e-16) + Dq1 * Dq3 * sin((2 * q5) + pi + (2 * q3) + 0.2e1 * q2 - 0.2e1 * q4) * 0.340000000000003452e-4 + Dq1 * cos(-q2 + pi / 0.2e1 - q3) * Dq3 * (-0.333199999999999996e0) + Dq1 * Dq2 * cos(-q2 + pi / 0.2e1 - q3) * (-0.333199999999999996e0) + Dq1 * Dq4 * cos(q5 + pi - q4 - q3) * (-0.260999999999999991e-2) + Dq1 * Dq4 * cos(q5 + pi - q4 + q3) * (-0.260999999999999991e-2) + Dq1 * Dq4 * cos(q5 + pi + q4 - q3) * 0.260999999999999991e-2 + Dq1 * Dq4 * cos(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + Dq1 * Dq5 * cos(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + Dq1 * Dq5 * cos(q5 + pi - q4 + q3) * 0.260999999999999991e-2 + Dq1 * Dq5 * cos(q5 + pi - q3) * (-0.521999999999999982e-2) + Dq1 * Dq5 * cos(q5 + pi + q3) * 0.521999999999999982e-2 + Dq1 * Dq5 * cos(q5 + pi + q4 - q3) * 0.260999999999999991e-2 + Dq1 * Dq5 * cos(q5 + pi - q4 - q3) * 0.260999999999999991e-2 + Dq1 * Dq2 * sin(0.2e1 * q4) * 0.492634362123101078e-16 + Dq1 * Dq2 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) * (-0.345589442479754540e-18) + Dq1 * Dq2 * cos(q5 + pi + q4 + q3) * 0.433680868994201774e-18 + Dq1 * Dq2 * cos(q5 + pi - q4 - q3) * (-0.433680868994201774e-18) + Dq1 * Dq2 * cos(q3) * 0.111022302462515654e-15 + Dq1 * Dq2 * cos(q5 + pi - q3) * 0.867361737988403548e-18 + Dq1 * Dq2 * cos(q5 + pi + q3) * 0.867361737988403548e-18 + Dq1 * Dq2 * sin(q5 + 0.2e1 * pi + 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * 0.433680868994201774e-18 + Dq1 * Dq2 * cos(-q3 - 0.2e1 * q2 + pi) * (-0.171360000000000001e1) + Dq1 * Dq2 * sin(q5 + 0.2e1 * pi - (2 * q3) - 0.2e1 * q2) * 0.110200000000000020e-1 + Dq1 * Dq2 * sin(q5 + 0.2e1 * q2 + (2 * q3)) * (-0.110200000000000020e-1) + Dq1 * Dq2 * cos(q5 + q3 + 0.2e1 * q2) * 0.104399999999999997e-1 + Dq1 * Dq2 * cos(q5 + 0.2e1 * pi - q3 - 0.2e1 * q2) * 0.104399999999999997e-1 + Dq1 * Dq2 * sin(0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * (-0.433680868994201774e-18) + Dq1 * Dq2 * sin(-0.2e1 * q2 + pi - (2 * q3)) * (-0.999310999999999948e0) + Dq1 * Dq2 * sin((2 * q5) + 0.3e1 * pi - (2 * q3) - 0.2e1 * q2) * (-0.203999999999999294e-3) + Dq1 * Dq2 * sin(-0.2e1 * q4 + (2 * q3) + 0.2e1 * q2 + q5) * (-0.650521303491302660e-18) + Dq1 * Dq2 * sin((2 * q5) + pi + (2 * q3) + 0.2e1 * q2) * 0.203999999999998779e-3 + Dq1 * Dq2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q4 - (2 * q3) - 0.2e1 * q2) * 0.650521303491302660e-18 + Dq1 * Dq2 * cos(q5 + pi - q4 + q3) * 0.433680868994201774e-18 + Dq1 * Dq2 * sin(-0.2e1 * q2 + pi) * 0.449054399999999986e1 + Dq1 * Dq2 * sin(-0.2e1 * q4 - (2 * q3) - 0.2e1 * q2 + pi) * 0.679999999999722440e-4 + Dq1 * Dq2 * sin(0.2e1 * pi - (2 * q3) + 0.2e1 * q4 + (2 * q5)) * (-0.172794721239877270e-18) + Dq1 * Dq2 * sin(-0.2e1 * q2 + 0.3e1 * pi + 0.2e1 * q4 + (2 * q5)) * 0.172794721239877270e-18 + Dq1 * Dq2 * sin((2 * q3)) * 0.111022302462515654e-15 + Dq1 * Dq2 * sin(0.2e1 * q2 - 0.2e1 * q4 + q5) * 0.216840434497100888e-18 + Dq1 * Dq2 * sin(pi + (2 * q3) + q5 - 0.2e1 * q4) * (-0.216840434497100888e-18) + Dq1 * Dq2 * sin(pi - (2 * q3) - 0.2e1 * q4 + q5) * 0.216840434497100888e-18 + Dq1 * Dq2 * sin(-0.2e1 * q2 + pi - 0.2e1 * q4) * (-0.215078605966811944e-16) + Dq1 * Dq2 * sin(0.2e1 * pi - (2 * q3) - 0.2e1 * q4 + (2 * q5)) * 0.172794721239877270e-18 + Dq1 * Dq2 * sin(-0.2e1 * q2 + 0.3e1 * pi - 0.2e1 * q4 + (2 * q5)) * (-0.172794721239877270e-18) + Dq1 * Dq2 * sin(pi - (2 * q3) + q5) * (-0.867361737988403548e-18) + Dq1 * Dq2 * sin(-0.2e1 * q2 + 0.2e1 * pi + q5) * 0.867361737988403548e-18 + Dq2 * Dq5 * sin(pi / 0.2e1 + 0.2e1 * q4 + q3 + q2 + q5) * (-0.433680868994201774e-18) + Dq2 * Dq5 * sin(0.3e1 / 0.2e1 * pi - 0.2e1 * q4 - q3 - q2 + q5) * (-0.433680868994201774e-18) + Dq2 * Dq5 * sin(q5 + pi / 0.2e1 - 0.2e1 * q4 + q3 + q2) * 0.433680868994201774e-18 + 0.7290000000e-3 * Dq2 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.7290000000e-3 * Dq2 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2) - 0.1121800000e0 * Dq2 * Dq4 * sin(-q2 + pi / 0.2e1 - q3) + 0.1360000000e-3 * Dq2 * Dq4 * sin(-0.2e1 * q4 - q3 - q2 + pi / 0.2e1) + 0.1360000000e-3 * Dq2 * Dq4 * sin(0.2e1 * q4 - q3 - q2 + pi / 0.2e1) + 0.6800000000e-4 * Dq2 * Dq4 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) - 0.1360000000e-3 * Dq2 * Dq4 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq2 * Dq4 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.6800000000e-4 * Dq2 * Dq4 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.1360000000e-3 * Dq2 * Dq4 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.6800000000e-4 * Dq2 * Dq5 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.6800000000e-4 * Dq2 * Dq5 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq2 * Dq5 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq2 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q4 - q3 - q2) * 0.433680868994201774e-18 + 0.6800000000e-4 * Dq2 * Dq5 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.1001000000e-2 * Dq2 * Dq5 * sin(-q4 - q3 - q2 + pi / 0.2e1) + 0.1360000000e-3 * Dq2 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.1360000000e-3 * Dq2 * Dq5 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + 0.1360000000e-3 * Dq2 * Dq5 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq2 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.1001000000e-2 * Dq2 * Dq5 * sin(q4 - q3 - q2 + pi / 0.2e1) - 0.3645000000e-3 * Dq2 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3645000000e-3 * Dq2 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.3645000000e-3 * Dq2 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.3645000000e-3 * Dq2 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.6800000000e-4 * Dq2 * Dq4 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq2 * Dq3 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) * 0.135999999999998618e-3 + Dq2 * Dq3 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) * (-0.135999999999998618e-3) + Dq2 * Dq3 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) * 0.135999999999998618e-3 + 0.6800000000e-4 * Dq2 * Dq3 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq2 * Dq3 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) * (-0.135999999999998618e-3) + Dq2 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.551000000000000101e-2 + 0.6800000000e-4 * Dq2 * Dq3 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.1360000000e-3 * Dq2 * Dq3 * sin(-0.2e1 * q4 - q3 - q2 + pi / 0.2e1) - 0.6800000000e-4 * Dq2 * Dq3 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) - 0.1360000000e-3 * Dq2 * Dq3 * sin(0.2e1 * q4 - q3 - q2 + pi / 0.2e1) + Dq2 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.551000000000000101e-2) + Dq2 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.551000000000000101e-2 - 0.6800000000e-4 * Dq2 * Dq3 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq2 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.551000000000000101e-2) + Dq3 * Dq5 * sin(pi / 0.2e1 + 0.2e1 * q4 + q3 + q2 + q5) * (-0.433680868994201774e-18) + Dq3 * Dq5 * sin(0.3e1 / 0.2e1 * pi - 0.2e1 * q4 - q3 - q2 + q5) * (-0.433680868994201774e-18) + Dq3 * Dq5 * sin(q5 + pi / 0.2e1 - 0.2e1 * q4 + q3 + q2) * 0.433680868994201774e-18 + Dq2 ^ 2 * sin(0.2e1 * q4 - q3 - q2 + pi / 0.2e1) * (-0.679999999999999994e-4) + Dq1 ^ 2 * sin(-q2 + pi / 0.2e1 - q3) * 0.346944695195361420e-17 + Dq4 ^ 2 * cos(q5 + pi - q4) * 0.101500000000000006e-2 + Dq4 ^ 2 * cos(q5 + pi + q4) * (-0.101500000000000006e-2) + Dq4 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.260999999999999991e-2) - 0.6800000000e-4 * Dq4 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + Dq4 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.275500000000000008e-2) + Dq4 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.275500000000000008e-2 + Dq5 ^ 2 * cos(q5 + pi / 0.2e1 + q4 + q2) * (-0.260999999999999991e-2) + Dq5 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.260999999999999991e-2) + Dq5 ^ 2 * cos(q5 + pi - q4) * 0.101500000000000006e-2 + Dq5 ^ 2 * cos(q5 + pi + q4) * (-0.101500000000000006e-2) + Dq5 ^ 2 * cos(q5 + pi / 0.2e1 - q4 + q2) * 0.260999999999999991e-2 + Dq5 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * 0.260999999999999991e-2 + Dq5 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.275500000000000008e-2) + Dq5 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.275500000000000008e-2) + Dq5 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.275500000000000008e-2 + Dq5 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.275500000000000008e-2 + Dq2 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) * 0.679999999999994844e-4 + Dq2 ^ 2 * cos(q5 + pi / 0.2e1 + q4 + q2) * 0.260999999999999991e-2 + Dq3 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.275500000000000052e-2) + Dq3 ^ 2 * sin(-q3 + q5 + pi / 0.2e1 - q4 + q2) * 0.216840434497100888e-18 + Dq3 ^ 2 * sin(q3 + q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * (-0.216840434497100888e-18) + Dq3 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.275500000000000052e-2 + Dq3 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.275500000000000052e-2 + Dq3 ^ 2 * sin(-q3 + q5 + pi / 0.2e1 + q4 + q2) * (-0.216840434497100888e-18) + Dq3 ^ 2 * sin(q3 + q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * 0.216840434497100888e-18 + Dq3 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.275500000000000052e-2) - 0.3400000000e-4 * Dq3 ^ 2 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.3400000000e-4 * Dq3 ^ 2 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) - 0.6800000000e-4 * Dq3 ^ 2 * sin(0.2e1 * q4 - q3 - q2 + pi / 0.2e1) + 0.6800000000e-4 * Dq3 ^ 2 * sin(-0.2e1 * q4 - q3 - q2 + pi / 0.2e1) + Dq3 ^ 2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) * (-0.679999999999999994e-4) + Dq3 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) * 0.679999999999999994e-4 + Dq3 ^ 2 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) * 0.679999999999999994e-4 + Dq3 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) * (-0.679999999999999994e-4) + 0.3400000000e-4 * Dq3 ^ 2 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.3400000000e-4 * Dq3 ^ 2 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq4 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.275500000000000008e-2 + Dq4 ^ 2 * cos(q5 + pi / 0.2e1 + q4 + q2) * (-0.260999999999999991e-2) + Dq4 ^ 2 * cos(q5 + pi / 0.2e1 - q4 + q2) * 0.260999999999999991e-2 + Dq4 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * 0.260999999999999991e-2 - 0.6800000000e-4 * Dq4 ^ 2 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + 0.6800000000e-4 * Dq4 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.6800000000e-4 * Dq4 ^ 2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) + Dq4 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.275500000000000008e-2) + Dq2 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.275500000000000052e-2 + Dq2 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.275500000000000052e-2) - 0.3400000000e-4 * Dq2 ^ 2 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq2 ^ 2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.275500000000000052e-2 + Dq2 ^ 2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) * (-0.679999999999994844e-4) + 0.3400000000e-4 * Dq2 ^ 2 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq2 ^ 2 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) * 0.679999999999994844e-4 - 0.3400000000e-4 * Dq2 ^ 2 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq2 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) * (-0.679999999999994844e-4) + Dq2 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * (-0.260999999999999991e-2) + Dq2 ^ 2 * sin(-0.2e1 * q4 - q3 - q2 + pi / 0.2e1) * 0.679999999999784916e-4 + 0.3400000000e-4 * Dq2 ^ 2 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq2 ^ 2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.275500000000000052e-2) + Dq2 ^ 2 * sin(-q2 + pi / 0.2e1 + 0.2e1 * q4 + q3) * 0.215078605966811944e-16 - 0.309540e0 * Dq2 ^ 2 * cos(-q2 + pi / 0.2e1) + Dq2 ^ 2 * sin(q2 + 0.3e1 / 0.2e1 * pi + (2 * q5) - q4 - q3) * (-0.169406589450860068e-18) + Dq2 ^ 2 * sin(-q2 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q4 + q3) * 0.169406589450860068e-18 + Dq2 ^ 2 * sin(-q3 + q5 + pi / 0.2e1 - q4 + q2) * (-0.216840434497100888e-18) + Dq2 ^ 2 * sin(q3 + q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.216840434497100888e-18) + Dq2 ^ 2 * sin(q2 + 0.3e1 / 0.2e1 * pi + (2 * q5) + q4 - q3) * 0.169406589450860068e-18 + Dq2 ^ 2 * sin(-q2 + 0.5e1 / 0.2e1 * pi + (2 * q5) + q4 + q3) * (-0.169406589450860068e-18) + Dq2 ^ 2 * sin(-q3 + q5 + pi / 0.2e1 + q4 + q2) * 0.216840434497100888e-18 + Dq2 ^ 2 * sin(q3 + q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * 0.216840434497100888e-18 + Dq2 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * 0.260999999999999991e-2 + Dq2 ^ 2 * cos(q5 + pi / 0.2e1 - q4 + q2) * (-0.260999999999999991e-2) + Dq1 ^ 2 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.863973606199386346e-19 + Dq1 ^ 2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) * (-0.345589442479754540e-18) + Dq1 ^ 2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.423516473627150169e-19 + Dq1 ^ 2 * sin(0.3e1 / 0.2e1 * pi - 0.2e1 * q4 - q3 - q2 + q5) * (-0.108420217248550444e-18) + Dq1 ^ 2 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) * 0.345589442479754540e-18 + Dq1 ^ 2 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) * (-0.440457132572236176e-19) + Dq1 ^ 2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) * 0.474338450462408190e-19 + Dq1 ^ 2 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) * (-0.128749007982653654e-18) + Dq1 ^ 2 * sin(0.3e1 * q2 + pi / 0.2e1 + (2 * q5) - q4 + q3) * 0.128749007982653654e-18 + Dq1 * Dq4 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.101500000000000006e-2 + Dq1 * Dq4 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.101500000000000006e-2) + Dq1 * Dq4 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.101500000000000006e-2) + Dq1 * Dq4 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.101500000000000006e-2 + Dq1 * Dq2 * cos(q5 + pi / 0.2e1 + q3 + q2) * 0.203000000000000012e-2 + Dq1 * Dq2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * 0.203000000000000012e-2 + Dq1 * Dq3 * cos(q5 + pi / 0.2e1 + q3 + q2) * 0.203000000000000012e-2 + Dq1 * Dq3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * 0.203000000000000012e-2 + Dq1 * Dq2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.101500000000000006e-2 + Dq1 * Dq2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.101500000000000006e-2) + Dq1 * Dq2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.101500000000000006e-2 + Dq1 * Dq2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.101500000000000006e-2) + Dq1 * Dq3 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.101500000000000006e-2 + Dq1 * Dq3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.101500000000000006e-2) + Dq1 * Dq3 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.101500000000000006e-2 + Dq1 * Dq3 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.101500000000000006e-2) + Dq5 * Dq1 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.101500000000000006e-2 + Dq5 * Dq1 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * 0.101500000000000006e-2 + Dq5 * Dq1 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.101500000000000006e-2 + Dq5 * Dq1 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.101500000000000006e-2 + Dq5 * Dq1 * cos(q5 + pi / 0.2e1 + q3 + q2) * 0.203000000000000012e-2 + Dq5 * Dq1 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * (-0.203000000000000012e-2);
cdq2 = Dq1 * Dq5 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * (-0.433680868994201774e-18) + 0.1121800000e0 * Dq1 * Dq4 * sin(-q2 + pi / 0.2e1 - q3) + 0.13600000e-3 * Dq1 * Dq4 * sin(-(2 * q4) - q3 - q2 + pi / 0.2e1) + 0.13600000e-3 * Dq1 * Dq4 * sin((2 * q4) - q3 - q2 + pi / 0.2e1) + 0.6800000000e-4 * Dq1 * Dq4 * sin(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq1 * Dq4 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * 0.216840434497100888e-18 + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.216840434497100888e-18) + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * (-0.433680868994201774e-18) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2) * 0.433680868994201774e-18 - 0.6800000000e-4 * Dq1 * Dq4 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.6800000000e-4 * Dq1 * Dq4 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * 0.216840434497100888e-18 - 0.6800000000e-4 * Dq1 * Dq5 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq5 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * 0.433680868994201774e-18 + Dq1 * Dq5 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.433680868994201774e-18 + sin(-q2 + pi / 0.2e1) * Dq1 ^ 2 * (-0.964739999999999932e0) + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * 0.867361737988403548e-18 + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2) * (-0.867361737988403548e-18) + Dq4 * Dq5 * cos(q5 + pi + q4 - q3) * (-0.521999999999999982e-2) + Dq1 * Dq4 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * (-0.521999999999999982e-2) + Dq1 * Dq4 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.521999999999999982e-2) + Dq1 * Dq4 * cos(q5 + pi / 0.2e1 - q4 + q2) * 0.521999999999999982e-2 + Dq1 * Dq4 * cos(q5 + pi / 0.2e1 + q4 + q2) * 0.521999999999999982e-2 + Dq1 * Dq5 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) * 0.521999999999999982e-2 + Dq1 * Dq5 * cos(q5 + pi / 0.2e1 + q4 + q2) * 0.521999999999999982e-2 + Dq1 * Dq5 * cos(q5 + pi / 0.2e1 - q4 + q2) * (-0.521999999999999982e-2) + Dq1 * Dq5 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) * (-0.521999999999999982e-2) + Dq2 * Dq3 * cos(q5 + pi + q3) * 0.104399999999999997e-1 + Dq2 * Dq3 * cos(q5 + pi + q4 - q3) * (-0.521999999999999982e-2) + Dq2 * Dq3 * cos(q3) * (-0.171359999999999979e1) + Dq2 * Dq3 * cos(q5 + pi + q4 + q3) * 0.521999999999999982e-2 + Dq2 * Dq3 * cos(q5 + pi - q4 - q3) * (-0.521999999999999982e-2) + Dq2 * Dq3 * cos(q5 + pi - q4 + q3) * 0.521999999999999982e-2 + Dq2 * Dq3 * cos(q5 + pi - q3) * 0.104399999999999997e-1 + Dq2 * Dq4 * cos(q5 + pi - q4 - q3) * (-0.521999999999999982e-2) + Dq2 * Dq4 * cos(q5 + pi - q4 + q3) * (-0.521999999999999982e-2) + Dq2 * Dq4 * cos(q5 + pi + q4 - q3) * 0.521999999999999982e-2 + Dq2 * Dq4 * cos(q5 + pi + q4 + q3) * 0.521999999999999982e-2 + Dq2 * Dq5 * cos(q5 + pi + q4 + q3) * 0.521999999999999982e-2 + Dq2 * Dq5 * cos(q5 + pi - q4 + q3) * 0.521999999999999982e-2 + Dq2 * Dq5 * cos(q5 + pi - q3) * (-0.104399999999999997e-1) + Dq2 * Dq5 * cos(q5 + pi + q3) * 0.104399999999999997e-1 + Dq2 * Dq5 * cos(q5 + pi + q4 - q3) * 0.521999999999999982e-2 + Dq2 * Dq5 * cos(q5 + pi - q4 - q3) * 0.521999999999999982e-2 + Dq3 * Dq4 * cos(q5 + pi - q4 - q3) * (-0.521999999999999982e-2) + Dq3 * Dq4 * cos(q5 + pi - q4 + q3) * (-0.521999999999999982e-2) + Dq3 * Dq4 * cos(q5 + pi + q4 - q3) * 0.521999999999999982e-2 + Dq3 * Dq4 * cos(q5 + pi + q4 + q3) * 0.521999999999999982e-2 + Dq3 * Dq5 * cos(q5 + pi + q4 + q3) * 0.521999999999999982e-2 + Dq3 * Dq5 * cos(q5 + pi - q4 + q3) * 0.521999999999999982e-2 + Dq3 * Dq5 * cos(q5 + pi - q3) * (-0.104399999999999997e-1) + Dq3 * Dq5 * cos(q5 + pi + q3) * 0.104399999999999997e-1 + Dq3 * Dq5 * cos(q5 + pi + q4 - q3) * 0.521999999999999982e-2 + Dq3 * Dq5 * cos(q5 + pi - q4 - q3) * 0.521999999999999982e-2 + Dq4 * Dq5 * cos(q5 + pi - q4 + q3) * (-0.521999999999999982e-2) + Dq4 * Dq5 * cos(q5 + pi + q4 + q3) * 0.521999999999999982e-2 + Dq4 * Dq5 * cos(q5 + pi - q4 - q3) * 0.521999999999999982e-2 + Dq5 * Dq1 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.551000000000000014e-2) + Dq5 * Dq1 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.551000000000000014e-2 + Dq5 * Dq1 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.551000000000000014e-2 + Dq5 * Dq1 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.551000000000000014e-2) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - 0.2e1 * q3 - 0.2e1 * q2) * 0.101999999999998969e-3 + Dq1 ^ 2 * sin(0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2 - (2 * q4)) * (-0.169999999999996544e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2) * (-0.101999999999999308e-3) + Dq1 ^ 2 * sin(0.2e1 * q5 + pi + (2 * q4) + 0.2e1 * q3 + 0.2e1 * q2) * (-0.169999999999996544e-4) + Dq1 ^ 2 * sin(-q4 + 0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2) * (-0.679999999999989694e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - 0.2e1 * q3 - 0.2e1 * q2 + (2 * q4)) * 0.169999999999996544e-4 + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi + q4 - 0.2e1 * q3 - 0.2e1 * q2) * (-0.680000000000007042e-4) + Dq1 ^ 2 * sin(q4 + 0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2) * (-0.679999999999989694e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - q4 - 0.2e1 * q3 - 0.2e1 * q2) * (-0.680000000000007042e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - (2 * q4) - 0.2e1 * q3 - 0.2e1 * q2) * 0.169999999999993088e-4 + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q3 - 0.2e1 * q2) * (-0.551000000000000101e-2) + Dq1 ^ 2 * sin(q5 + 0.2e1 * q2 + 0.2e1 * q3) * 0.551000000000000101e-2 - 0.1015000000e-2 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2) - 0.1015000000e-2 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.433680868994201774e-18) + Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.433680868994201774e-18) + Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.433680868994201774e-18 + Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.433680868994201774e-18 - 0.6800000000e-4 * Dq1 * Dq5 * sin(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq1 * Dq5 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.433680868994201774e-18) + 0.6800000000e-4 * Dq1 * Dq5 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq1 * Dq4 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * (-0.216840434497100888e-18) + Dq1 ^ 2 * cos(q5 - q4 + q3 + 0.2e1 * q2) * (-0.260999999999999991e-2) + Dq1 ^ 2 * cos(q5 + 0.2e1 * pi + q4 - q3 - 0.2e1 * q2) * 0.260999999999999991e-2 + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.433680868994201774e-18 + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.433680868994201774e-18 + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.433680868994201774e-18) + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.433680868994201774e-18) + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.551000000000000014e-2) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.551000000000000014e-2) + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.551000000000000014e-2) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.551000000000000014e-2) + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - q4 - 0.2e1 * q3 - 0.2e1 * q2) * 0.275500000000000008e-2 + Dq1 ^ 2 * sin(q5 + q4 + 0.2e1 * q3 + 0.2e1 * q2) * 0.275500000000000008e-2 + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q2 - 0.2e1 * q3 + q4) * 0.275500000000000008e-2 + Dq1 ^ 2 * sin(q5 + 0.2e1 * q2 + 0.2e1 * q3 - q4) * 0.275500000000000008e-2 - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + Dq1 ^ 2 * cos(q5 + q4 + q3 + 0.2e1 * q2) * (-0.260999999999999991e-2) + Dq1 ^ 2 * cos(q5 + 0.2e1 * pi - q4 - q3 - 0.2e1 * q2) * 0.260999999999999991e-2 + cos(q3) * Dq1 ^ 2 * 0.555111512312578272e-16 + cos(q3) * Dq2 ^ 2 * 0.111022302462515654e-15 + Dq1 ^ 2 * cos(-q2 + pi / 0.2e1 - q3) * 0.166600000000000026e0 + Dq1 ^ 2 * cos(-q3 - 0.2e1 * q2 + pi) * 0.856799999999999894e0 + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * 0.867361737988403548e-18 - 0.6800000000e-4 * Dq1 * Dq4 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq2 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * (-0.867361737988403548e-18) + Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.867361737988403548e-18) + Dq1 * Dq2 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * 0.867361737988403548e-18 + Dq1 * Dq2 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.867361737988403548e-18 + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.867361737988403548e-18) + Dq2 ^ 2 * sin(q5 + pi + q4) * (-0.433680868994201774e-18) + Dq1 ^ 2 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) * 0.345589442479754540e-18 + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) * 0.345589442479754540e-18 + Dq1 ^ 2 * sin(-0.2e1 * q2 + pi) * (-0.224527199999999994e1) + Dq2 * Dq5 * sin(pi - (2 * q4) + q5) * (-0.867361737988403548e-18) - 0.7290000000e-3 * Dq6 * Dq5 * sin(q5 + pi + q4) + 0.7290000000e-3 * Dq6 * Dq5 * sin(q5 + pi - q4) + Dq4 * Dq5 * sin(q5 + pi - q4) * (-0.110200000000000003e-1) + Dq4 * Dq5 * sin(q5 + pi + q4) * 0.110200000000000003e-1 + 0.2720000000e-3 * Dq4 * Dq5 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) - 0.2002000000e-2 * Dq4 * Dq5 * sin(q4) - 0.2720000000e-3 * Dq4 * Dq5 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) - 0.7290000000e-3 * Dq4 * Dq6 * sin(q5 + pi + q4) - 0.7290000000e-3 * Dq4 * Dq6 * sin(q5 + pi - q4) - 0.27200000e-3 * Dq3 * Dq4 * sin((2 * q4)) + 0.1360000000e-3 * Dq3 * Dq4 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.1360000000e-3 * Dq3 * Dq4 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.2720000000e-3 * Dq3 * Dq5 * sin(0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq3 * Dq5 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq3 * Dq5 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + Dq3 * Dq5 * sin(pi + (2 * q4) + q5) * (-0.867361737988403548e-18) + Dq3 * Dq5 * sin(q5 + pi) * 0.220399999999999971e-1 + Dq3 * Dq5 * sin(pi - (2 * q4) + q5) * (-0.867361737988403548e-18) + Dq1 * Dq3 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.173472347597680710e-17 + Dq1 * Dq3 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * (-0.173472347597680710e-17) + Dq1 * Dq2 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) * 0.691178884959509077e-18 + Dq1 * Dq2 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.138235776991901816e-17 + Dq1 * Dq2 * sin(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) * (-0.691178884959509077e-18) + Dq1 * Dq2 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * (-0.691178884959509077e-18) + Dq1 * Dq3 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) * 0.138235776991901816e-17 + Dq1 * Dq3 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.138235776991901816e-17 + Dq1 * Dq3 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * (-0.138235776991901816e-17) + 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq1 * Dq4 * sin(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.7290000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.7290000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) + Dq4 ^ 2 * cos(q5 + pi - q4 + q3) * 0.260999999999999991e-2 + Dq4 ^ 2 * cos(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + Dq4 ^ 2 * cos(q5 + pi - q4 - q3) * (-0.260999999999999991e-2) + Dq4 ^ 2 * cos(q5 + pi + q4 - q3) * (-0.260999999999999991e-2) + Dq3 ^ 2 * cos(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + Dq3 ^ 2 * cos(q3) * (-0.856799999999999894e0) + Dq3 ^ 2 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) * (-0.691178884959509077e-18) + Dq3 ^ 2 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) * (-0.691178884959509077e-18) + Dq3 ^ 2 * cos(q5 + pi - q3) * 0.521999999999999982e-2 + Dq3 ^ 2 * cos(q5 + pi + q4 - q3) * (-0.260999999999999991e-2) + Dq3 ^ 2 * cos(q5 + pi - q4 - q3) * (-0.260999999999999991e-2) + Dq3 ^ 2 * cos(q5 + pi - q4 + q3) * 0.260999999999999991e-2 + Dq3 ^ 2 * cos(q5 + pi + q3) * 0.521999999999999982e-2 + Dq5 ^ 2 * cos(q5 + pi + q3) * 0.521999999999999982e-2 + Dq5 ^ 2 * cos(q5 + pi - q3) * 0.521999999999999982e-2 + Dq5 ^ 2 * cos(q5 + pi + q4 + q3) * 0.260999999999999991e-2 + Dq5 ^ 2 * cos(q5 + pi - q4 - q3) * (-0.260999999999999991e-2) + Dq5 ^ 2 * cos(q5 + pi - q4 + q3) * 0.260999999999999991e-2 + Dq5 ^ 2 * cos(q5 + pi + q4 - q3) * (-0.260999999999999991e-2) + Dq1 ^ 2 * sin((2 * q4) + 0.2e1 * q3 + 0.2e1 * q2 + q5) * (-0.216840434497100888e-18) + Dq1 ^ 2 * sin(-0.2e1 * q2 + pi - 0.2e1 * q3) * 0.499655499999999974e0 + Dq1 ^ 2 * sin(-(2 * q4) + 0.2e1 * q3 + 0.2e1 * q2 + q5) * (-0.216840434497100888e-18) + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - (2 * q4) - 0.2e1 * q3 - 0.2e1 * q2) * 0.216840434497100888e-18 + Dq1 ^ 2 * sin(q5 + pi - q4) * (-0.433680868994201774e-18) + Dq1 ^ 2 * sin(q5 + pi + q4) * (-0.433680868994201774e-18) + Dq3 ^ 2 * sin(q5 + pi + q4) * (-0.433680868994201774e-18) + Dq3 ^ 2 * sin(q5 + pi - q4) * (-0.433680868994201774e-18) + Dq4 ^ 2 * sin(q5 + pi + q4) * 0.551000000000000014e-2 + Dq4 ^ 2 * sin(q5 + pi - q4) * 0.551000000000000014e-2 - 0.1360000000e-3 * Dq4 ^ 2 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) - 0.1360000000e-3 * Dq4 ^ 2 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) + Dq5 ^ 2 * sin(q5 + pi - q4) * 0.551000000000000014e-2 + Dq5 ^ 2 * sin(q5 + pi + q4) * 0.551000000000000014e-2 + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi + (2 * q4) - 0.2e1 * q3 - 0.2e1 * q2) * 0.216840434497100888e-18 + Dq2 ^ 2 * sin(q5 + pi - q4) * (-0.433680868994201774e-18) + Dq1 ^ 2 * cos(q5 + q3 + 0.2e1 * q2) * (-0.521999999999999982e-2) + Dq1 ^ 2 * cos(q5 + 0.2e1 * pi - q3 - 0.2e1 * q2) * (-0.521999999999999982e-2) + Dq2 * Dq3 * sin(q5 + pi + q4) * (-0.173472347597680710e-17) + Dq2 * Dq3 * sin(q5 + pi - q4) * (-0.173472347597680710e-17) + Dq2 * Dq3 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) * (-0.138235776991901816e-17) + Dq2 * Dq3 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) * (-0.138235776991901816e-17) - 0.27200000e-3 * Dq2 * Dq4 * sin((2 * q4)) + 0.1360000000e-3 * Dq2 * Dq4 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.1360000000e-3 * Dq2 * Dq4 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.2720000000e-3 * Dq2 * Dq5 * sin(0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq2 * Dq5 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq2 * Dq5 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + Dq2 * Dq5 * sin(pi + (2 * q4) + q5) * (-0.867361737988403548e-18) + Dq2 * Dq5 * sin(q5 + pi) * 0.220399999999999971e-1 + Dq1 * Dq3 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q5) * 0.138235776991901816e-17 - 0.1001000000e-2 * Dq1 * Dq5 * sin(-q4 - q3 - q2 + pi / 0.2e1) + 0.1360000000e-3 * Dq1 * Dq5 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq5 * sin(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) + 0.1360000000e-3 * Dq1 * Dq5 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq5 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.1001000000e-2 * Dq1 * Dq5 * sin(q4 - q3 - q2 + pi / 0.2e1) + Dq1 * Dq2 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.691178884959509077e-18 + Dq1 ^ 2 * sin(-(2 * q4) - 0.2e1 * q3 - 0.2e1 * q2 + pi) * (-0.340000000000062474e-4) + Dq1 ^ 2 * sin((2 * q4) - 0.2e1 * q3 - 0.2e1 * q2 + pi) * (-0.340000000000201252e-4);
cdq3 = Dq1 * Dq5 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * (-0.433680868994201774e-18) + 0.1121800000e0 * Dq1 * Dq4 * sin(-q2 + pi / 0.2e1 - q3) + 0.13600000e-3 * Dq1 * Dq4 * sin(-(2 * q4) - q3 - q2 + pi / 0.2e1) + 0.13600000e-3 * Dq1 * Dq4 * sin((2 * q4) - q3 - q2 + pi / 0.2e1) + 0.6800000000e-4 * Dq1 * Dq4 * sin(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq1 * Dq4 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * 0.216840434497100888e-18 + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.216840434497100888e-18) + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * (-0.433680868994201774e-18) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2) * 0.433680868994201774e-18 - 0.6800000000e-4 * Dq1 * Dq4 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.6800000000e-4 * Dq1 * Dq4 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * 0.216840434497100888e-18 - 0.6800000000e-4 * Dq1 * Dq5 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq5 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * 0.433680868994201774e-18 + Dq1 * Dq5 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.433680868994201774e-18 + Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * (-0.867361737988403548e-18) + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) * (-0.867361737988403548e-18) + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2) * (-0.867361737988403548e-18) + Dq5 * Dq1 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.551000000000000014e-2) + Dq5 * Dq1 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * 0.551000000000000014e-2 + Dq5 * Dq1 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.551000000000000014e-2 + Dq5 * Dq1 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.551000000000000014e-2) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - 0.2e1 * q3 - 0.2e1 * q2) * 0.102000000000000176e-3 + Dq1 ^ 2 * sin(0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2 - (2 * q4)) * (-0.170000000000001760e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2) * (-0.102000000000000176e-3) + Dq1 ^ 2 * sin(0.2e1 * q5 + pi + (2 * q4) + 0.2e1 * q3 + 0.2e1 * q2) * (-0.170000000000000000e-4) + Dq1 ^ 2 * sin(-q4 + 0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2) * (-0.679999999999989694e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - 0.2e1 * q3 - 0.2e1 * q2 + (2 * q4)) * 0.170000000000001760e-4 + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi + q4 - 0.2e1 * q3 - 0.2e1 * q2) * (-0.679999999999994844e-4) + Dq1 ^ 2 * sin(q4 + 0.2e1 * q5 + pi + 0.2e1 * q3 + 0.2e1 * q2) * (-0.679999999999989694e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - q4 - 0.2e1 * q3 - 0.2e1 * q2) * (-0.679999999999994844e-4) + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.3e1 * pi - (2 * q4) - 0.2e1 * q3 - 0.2e1 * q2) * 0.170000000000000000e-4 + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q3 - 0.2e1 * q2) * (-0.551000000000000101e-2) + Dq1 ^ 2 * sin(q5 + 0.2e1 * q2 + 0.2e1 * q3) * 0.551000000000000101e-2 - 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + pi - q3) - 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + pi + q3) - 0.5220000000e-2 * Dq2 ^ 2 * cos(q5 + pi - q3) - 0.5220000000e-2 * Dq2 ^ 2 * cos(q5 + pi + q3) - 0.1015000000e-2 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2) - 0.1015000000e-2 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.433680868994201774e-18) + Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.433680868994201774e-18) + Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.433680868994201774e-18 + Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.433680868994201774e-18 - 0.6800000000e-4 * Dq1 * Dq5 * sin(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq1 * Dq5 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq5 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.433680868994201774e-18) + 0.6800000000e-4 * Dq1 * Dq5 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) + Dq1 * Dq4 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * (-0.216840434497100888e-18) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 - q4 + q3 + 0.2e1 * q2) + 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + 0.2e1 * pi + q4 - q3 - 0.2e1 * q2) + 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi + q4 - q3) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi - q4 + q3) + 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi - q4 - q3) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi + q4 + q3) + 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi + q4 - q3) - 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi - q4 + q3) + Dq1 * Dq2 * sin(-q2 + pi / 0.2e1 - q3) * (-0.111022302462515654e-15) + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * 0.433680868994201774e-18 + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * 0.433680868994201774e-18 + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.433680868994201774e-18) + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.433680868994201774e-18) + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) * (-0.551000000000000014e-2) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) * (-0.551000000000000014e-2) + Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) * (-0.551000000000000014e-2) + Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) * (-0.551000000000000014e-2) + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - q4 - 0.2e1 * q3 - 0.2e1 * q2) * 0.275500000000000008e-2 + Dq1 ^ 2 * sin(q5 + q4 + 0.2e1 * q3 + 0.2e1 * q2) * 0.275500000000000008e-2 + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q2 - 0.2e1 * q3 + q4) * 0.275500000000000008e-2 + Dq1 ^ 2 * sin(q5 + 0.2e1 * q2 + 0.2e1 * q3 - q4) * 0.275500000000000008e-2 - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + q4 + q3 + 0.2e1 * q2) + 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + 0.2e1 * pi - q4 - q3 - 0.2e1 * q2) + 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi - q4 - q3) - 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi + q4 + q3) + cos(q3) * Dq1 ^ 2 * 0.428400000000000002e0 + cos(q3) * Dq2 ^ 2 * 0.856800000000000006e0 + Dq1 ^ 2 * cos(-q2 + pi / 0.2e1 - q3) * 0.166600000000000026e0 + Dq1 ^ 2 * cos(-q3 - 0.2e1 * q2 + pi) * 0.428400000000000002e0 + Dq1 * Dq3 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * 0.867361737988403548e-18 - 0.6800000000e-4 * Dq1 * Dq4 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + Dq1 * Dq2 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * (-0.173472347597680710e-17) + Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.173472347597680710e-17) + Dq1 * Dq2 * sin(q5 + pi / 0.2e1 - (2 * q4) + q3 + q2) * 0.173472347597680710e-17 + Dq1 * Dq2 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.867361737988403548e-18 + Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi + (2 * q4) - q3 - q2) * (-0.173472347597680710e-17) + Dq2 ^ 2 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) * (-0.138235776991901816e-17) + Dq2 ^ 2 * sin(q5 + pi + q4) * (-0.433680868994201774e-18) + Dq1 ^ 2 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) * 0.691178884959509077e-18 + Dq1 ^ 2 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) * 0.691178884959509077e-18 + Dq2 * Dq5 * sin(pi - (2 * q4) + q5) * (-0.867361737988403548e-18) - 0.7290000000e-3 * Dq6 * Dq5 * sin(q5 + pi + q4) + 0.7290000000e-3 * Dq6 * Dq5 * sin(q5 + pi - q4) + Dq4 * Dq5 * sin(q5 + pi - q4) * (-0.110200000000000003e-1) + Dq4 * Dq5 * sin(q5 + pi + q4) * 0.110200000000000003e-1 + 0.2720000000e-3 * Dq4 * Dq5 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) - 0.2002000000e-2 * Dq4 * Dq5 * sin(q4) - 0.2720000000e-3 * Dq4 * Dq5 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) - 0.7290000000e-3 * Dq4 * Dq6 * sin(q5 + pi + q4) - 0.7290000000e-3 * Dq4 * Dq6 * sin(q5 + pi - q4) - 0.27200000e-3 * Dq3 * Dq4 * sin((2 * q4)) + 0.1360000000e-3 * Dq3 * Dq4 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.1360000000e-3 * Dq3 * Dq4 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.2720000000e-3 * Dq3 * Dq5 * sin(0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq3 * Dq5 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq3 * Dq5 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + Dq3 * Dq5 * sin(pi + (2 * q4) + q5) * (-0.867361737988403548e-18) + Dq3 * Dq5 * sin(q5 + pi) * 0.220399999999999971e-1 + Dq3 * Dq5 * sin(pi - (2 * q4) + q5) * (-0.867361737988403548e-18) + Dq1 * Dq3 * sin(0.3e1 / 0.2e1 * pi - (2 * q4) - q3 - q2 + q5) * 0.867361737988403548e-18 + Dq1 * Dq3 * sin(pi / 0.2e1 + (2 * q4) + q3 + q2 + q5) * (-0.173472347597680710e-17) + Dq1 * Dq2 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) * 0.138235776991901816e-17 + Dq1 * Dq2 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.138235776991901816e-17 + Dq1 * Dq2 * sin(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) * (-0.138235776991901816e-17) + Dq1 * Dq2 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * (-0.138235776991901816e-17) + Dq1 * Dq3 * sin(-(2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) * (-0.691178884959509077e-18) + Dq1 * Dq3 * sin((2 * q4) + 0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q3 + q2) * 0.138235776991901816e-17 + Dq1 * Dq3 * sin((2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.138235776991901816e-17 + Dq1 * Dq3 * sin(-(2 * q4) + 0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * (-0.691178884959509077e-18) + 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq1 * Dq4 * sin(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq4 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.7290000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.7290000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) + Dq1 ^ 2 * sin((2 * q4) + 0.2e1 * q3 + 0.2e1 * q2 + q5) * (-0.216840434497100888e-18) + Dq1 ^ 2 * sin(-0.2e1 * q2 + pi - 0.2e1 * q3) * 0.499655500000000030e0 + Dq1 ^ 2 * sin(-(2 * q4) + 0.2e1 * q3 + 0.2e1 * q2 + q5) * (-0.216840434497100888e-18) + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - (2 * q4) - 0.2e1 * q3 - 0.2e1 * q2) * 0.216840434497100888e-18 + Dq1 ^ 2 * sin(q5 + pi - q4) * (-0.433680868994201774e-18) + Dq1 ^ 2 * sin(q5 + pi + q4) * (-0.433680868994201774e-18) + Dq3 ^ 2 * sin(q5 + pi + q4) * 0.433680868994201774e-18 + Dq3 ^ 2 * sin(q5 + pi - q4) * 0.433680868994201774e-18 + Dq4 ^ 2 * sin(q5 + pi + q4) * 0.551000000000000014e-2 + Dq4 ^ 2 * sin(q5 + pi - q4) * 0.551000000000000014e-2 - 0.1360000000e-3 * Dq4 ^ 2 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) - 0.1360000000e-3 * Dq4 ^ 2 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) + Dq5 ^ 2 * sin(q5 + pi - q4) * 0.551000000000000014e-2 + Dq5 ^ 2 * sin(q5 + pi + q4) * 0.551000000000000014e-2 + Dq1 ^ 2 * sin(q5 + 0.2e1 * pi + (2 * q4) - 0.2e1 * q3 - 0.2e1 * q2) * 0.216840434497100888e-18 + Dq2 ^ 2 * sin(q5 + pi - q4) * (-0.433680868994201774e-18) + Dq2 ^ 2 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) * (-0.138235776991901816e-17) - 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + q3 + 0.2e1 * q2) - 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + 0.2e1 * pi - q3 - 0.2e1 * q2) + Dq2 * Dq3 * sin(q5 + pi + q4) * (-0.173472347597680710e-17) + Dq2 * Dq3 * sin(q5 + pi - q4) * (-0.173472347597680710e-17) + Dq2 * Dq3 * sin(q4 + 0.2e1 * pi + 0.2e1 * q5) * (-0.276471553983803630e-17) + Dq2 * Dq3 * sin(0.2e1 * q5 + 0.2e1 * pi - q4) * (-0.276471553983803630e-17) - 0.27200000e-3 * Dq2 * Dq4 * sin((2 * q4)) + 0.1360000000e-3 * Dq2 * Dq4 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.1360000000e-3 * Dq2 * Dq4 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) - 0.2720000000e-3 * Dq2 * Dq5 * sin(0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq2 * Dq5 * sin(-(2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + 0.1360000000e-3 * Dq2 * Dq5 * sin((2 * q4) + 0.2e1 * pi + 0.2e1 * q5) + Dq2 * Dq5 * sin(pi + (2 * q4) + q5) * (-0.867361737988403548e-18) + Dq2 * Dq5 * sin(q5 + pi) * 0.220399999999999971e-1 + Dq1 * Dq3 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + 0.2e1 * q5) * 0.691178884959509077e-18 + Dq1 * Dq3 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi - q3 - q2) * 0.691178884959509077e-18 - 0.1001000000e-2 * Dq1 * Dq5 * sin(-q4 - q3 - q2 + pi / 0.2e1) + 0.1360000000e-3 * Dq1 * Dq5 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq5 * sin(-q4 + 0.5e1 / 0.2e1 * pi + 0.2e1 * q5 - q3 - q2) + 0.1360000000e-3 * Dq1 * Dq5 * sin(0.2e1 * q5 + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq5 * sin(0.2e1 * q5 + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.1001000000e-2 * Dq1 * Dq5 * sin(q4 - q3 - q2 + pi / 0.2e1) + Dq1 * Dq2 * sin(-(2 * q4) - q3 - q2 + pi / 0.2e1) * 0.111022302462515654e-15 + Dq1 ^ 2 * sin(-(2 * q4) - 0.2e1 * q3 - 0.2e1 * q2 + pi) * (-0.339999999999923696e-4) + Dq1 ^ 2 * sin((2 * q4) - 0.2e1 * q3 - 0.2e1 * q2 + pi) * (-0.340000000000062474e-4);
cdq4 = 0.5440000000e-3 * Dq5 * Dq4 * sin((2 * pi + 2 * q5)) + 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5 + pi + 2 * q3 + 2 * q2 - 2 * q4)) + 0.6800000000e-4 * Dq2 ^ 2 * sin((-2 * q4 + 2 * pi + 2 * q5)) - 0.6800000000e-4 * Dq2 ^ 2 * sin((2 * q4 + 2 * pi + 2 * q5)) + 0.6800000000e-4 * Dq3 ^ 2 * sin((-2 * q4 + 2 * pi + 2 * q5)) - 0.6800000000e-4 * Dq3 ^ 2 * sin((2 * q4 + 2 * pi + 2 * q5)) - 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5 + pi + 2 * q4 + 2 * q3 + 2 * q2)) + 0.3400000000e-4 * Dq1 ^ 2 * sin((2 * q4 + 2 * pi + 2 * q5)) + 0.3400000000e-4 * Dq1 ^ 2 * sin((-q4 + 2 * q5 + pi + 2 * q3 + 2 * q2)) - 0.3400000000e-4 * Dq1 ^ 2 * sin((-2 * q4 + 2 * pi + 2 * q5)) - 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5 + 3 * pi - 2 * q3 - 2 * q2 + 2 * q4)) + 0.3400000000e-4 * Dq1 ^ 2 * sin((2 * q5 + 3 * pi + q4 - 2 * q3 - 2 * q2)) - 0.3400000000e-4 * Dq1 ^ 2 * sin((q4 + 2 * q5 + pi + 2 * q3 + 2 * q2)) - 0.3400000000e-4 * Dq1 ^ 2 * sin((2 * q5 + 3 * pi - q4 - 2 * q3 - 2 * q2)) + 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5 + 3 * pi - 2 * q4 - 2 * q3 - 2 * q2)) + 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.1121800000e0 * Dq1 * sin(-q2 + pi / 0.2e1 - q3) * Dq3 - 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + pi / 0.2e1 + q4 + q2) + 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) - 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + pi / 0.2e1 - q4 + q2) + 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) + 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 - q4 + q3 + 2 * q2)) - 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 + 2 * pi + q4 - q3 - 2 * q2)) - 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 + pi + q4 - q3)) + 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 + pi - q4 + q3)) + 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 + pi - q4 - q3)) - 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 + pi + q4 + q3)) - 0.2610000000e-2 * Dq2 ^ 2 * cos((q5 + pi + q4 - q3)) + 0.2610000000e-2 * Dq2 ^ 2 * cos((q5 + pi - q4 + q3)) + 0.1458000000e-2 * sin((q5 + pi)) * Dq5 * Dq6 - 0.1121800000e0 * Dq1 * Dq2 * sin(-q2 + pi / 0.2e1 - q3) + 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.1377500000e-2 * Dq1 ^ 2 * sin((q5 + 2 * pi - q4 - 2 * q3 - 2 * q2)) + 0.1377500000e-2 * Dq1 ^ 2 * sin((q5 + q4 + 2 * q3 + 2 * q2)) - 0.1377500000e-2 * Dq1 ^ 2 * sin((q5 + 2 * pi - 2 * q2 - 2 * q3 + q4)) - 0.1377500000e-2 * Dq1 ^ 2 * sin((q5 + 2 * q2 + 2 * q3 - q4)) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 + q4 + q3 + 2 * q2)) + 0.1305000000e-2 * Dq1 ^ 2 * cos((q5 + 2 * pi - q4 - q3 - 2 * q2)) + 0.2610000000e-2 * Dq2 ^ 2 * cos((q5 + pi - q4 - q3)) - 0.2610000000e-2 * Dq2 ^ 2 * cos((q5 + pi + q4 + q3)) - 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.6800000000e-4 * Dq1 * Dq2 * sin((2 * q4) + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq1 * Dq2 * sin((2 * q4) + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.6800000000e-4 * Dq1 * Dq2 * sin(-(2 * q4) + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.6800000000e-4 * Dq1 * Dq2 * sin(-(2 * q4) + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq2 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) - 0.6800000000e-4 * Dq1 * Dq3 * sin(-(2 * q4) + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq3 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.6800000000e-4 * Dq1 * Dq3 * sin((2 * q4) + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq1 * Dq3 * sin((2 * q4) + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.6800000000e-4 * Dq1 * Dq3 * sin(-(2 * q4) + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.1360000000e-3 * Dq2 * Dq3 * sin((2 * q4 + 2 * pi + 2 * q5)) + 0.1360000000e-3 * Dq2 * Dq3 * sin((-2 * q4 + 2 * pi + 2 * q5)) + 0.7290000000e-3 * Dq2 * Dq6 * sin((q5 + pi + q4)) + 0.7290000000e-3 * Dq2 * Dq6 * sin((q5 + pi - q4)) + 0.7290000000e-3 * Dq3 * Dq6 * sin((q5 + pi + q4)) + 0.7290000000e-3 * Dq3 * Dq6 * sin((q5 + pi - q4)) - 0.1360000000e-3 * Dq1 * Dq3 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) + 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq3 * sin(-(2 * q4) - q3 - q2 + pi / 0.2e1) - 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q4) - q3 - q2 + pi / 0.2e1) - 0.1001000000e-2 * Dq1 * Dq5 * sin(-q4 - q3 - q2 + pi / 0.2e1) - 0.1360000000e-3 * Dq1 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.2720000000e-3 * Dq1 * Dq5 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.1360000000e-3 * Dq1 * Dq5 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) - 0.2720000000e-3 * Dq1 * Dq5 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) + 0.1360000000e-3 * Dq1 * Dq5 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq5 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.1001000000e-2 * Dq1 * Dq5 * sin(q4 - q3 - q2 + pi / 0.2e1) + 0.2720000e-3 * Dq2 * Dq3 * sin((2 * q4)) + 0.2720000000e-3 * Dq2 * Dq5 * sin((2 * q5 + 2 * pi - q4)) - 0.2720000000e-3 * Dq2 * Dq5 * sin((q4 + 2 * pi + 2 * q5)) + 0.2002000000e-2 * Dq2 * Dq5 * sin(q4) + 0.2720000000e-3 * Dq3 * Dq5 * sin((2 * q5 + 2 * pi - q4)) - 0.2720000000e-3 * Dq3 * Dq5 * sin((q4 + 2 * pi + 2 * q5)) + 0.2002000000e-2 * Dq3 * Dq5 * sin(q4) - 0.1360000000e-3 * Dq1 * Dq2 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) - 0.1360000e-3 * Dq1 * Dq2 * sin(-(2 * q4) - q3 - q2 + pi / 0.2e1) + 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.1360000e-3 * Dq1 * Dq2 * sin((2 * q4) - q3 - q2 + pi / 0.2e1) + 0.1360000e-3 * Dq2 ^ 2 * sin((2 * q4)) + 0.1360000e-3 * Dq3 ^ 2 * sin((2 * q4)) - 0.3400000000e-4 * Dq1 ^ 2 * sin((-2 * q4 - 2 * q3 - 2 * q2 + pi)) + 0.340000e-4 * Dq1 ^ 2 * sin((2 * q4 - 2 * q3 - 2 * q2 + pi)) - 0.6800000000e-4 * Dq1 ^ 2 * sin((2 * q4));
cdq5 = 0.1001000000e-2 * Dq4 * Dq1 * sin(-q4 - q3 - q2 + pi / 0.2e1) + 0.1001000000e-2 * Dq4 * Dq1 * sin(q4 - q3 - q2 + pi / 0.2e1) - 0.2002000000e-2 * Dq4 * sin(q4) * Dq2 - 0.2002000000e-2 * Dq4 * sin(q4) * Dq3 - 0.1001000000e-2 * Dq1 * Dq2 * sin(q4 - q3 - q2 + pi / 0.2e1) + 0.1001000000e-2 * Dq1 * Dq2 * sin(-q4 - q3 - q2 + pi / 0.2e1) - 0.1001000000e-2 * Dq1 * Dq3 * sin(q4 - q3 - q2 + pi / 0.2e1) + 0.1001000000e-2 * Dq1 * Dq3 * sin(-q4 - q3 - q2 + pi / 0.2e1) - 0.2720000000e-3 * Dq4 ^ 2 * sin(0.2e1 * pi + (2 * q5)) - 0.1102000000e-1 * sin(q5 + pi) * Dq3 ^ 2 - 0.1102000000e-1 * sin(q5 + pi) * Dq2 ^ 2 - 0.5510000000e-2 * sin(q5 + pi) * Dq1 ^ 2 - 0.1020000000e-3 * Dq1 ^ 2 * sin((2 * q5) + 0.3e1 * pi - 0.2e1 * q3 - 0.2e1 * q2) - 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5) + pi + 0.2e1 * q3 + 0.2e1 * q2 - 0.2e1 * q4) - 0.1020000000e-3 * Dq1 ^ 2 * sin((2 * q5) + pi + 0.2e1 * q3 + 0.2e1 * q2) + 0.1360000000e-3 * Dq2 ^ 2 * sin(0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq2 ^ 2 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq2 ^ 2 * sin(0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) + 0.1360000000e-3 * Dq3 ^ 2 * sin(0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq3 ^ 2 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq3 ^ 2 * sin(0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) - 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5) + pi + 0.2e1 * q4 + 0.2e1 * q3 + 0.2e1 * q2) + 0.3400000000e-4 * Dq1 ^ 2 * sin(0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq1 ^ 2 * sin(-q4 + (2 * q5) + pi + 0.2e1 * q3 + 0.2e1 * q2) + 0.3400000000e-4 * Dq1 ^ 2 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) - 0.6800000000e-4 * Dq1 ^ 2 * sin(0.2e1 * pi + (2 * q5)) - 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5) + 0.3e1 * pi - 0.2e1 * q3 - 0.2e1 * q2 + 0.2e1 * q4) + 0.6800000000e-4 * Dq1 ^ 2 * sin((2 * q5) + 0.3e1 * pi + q4 - 0.2e1 * q3 - 0.2e1 * q2) - 0.6800000000e-4 * Dq1 ^ 2 * sin(q4 + (2 * q5) + pi + 0.2e1 * q3 + 0.2e1 * q2) + 0.6800000000e-4 * Dq1 ^ 2 * sin((2 * q5) + 0.3e1 * pi - q4 - 0.2e1 * q3 - 0.2e1 * q2) - 0.1700000000e-4 * Dq1 ^ 2 * sin((2 * q5) + 0.3e1 * pi - 0.2e1 * q4 - 0.2e1 * q3 - 0.2e1 * q2) + 0.2755000000e-2 * Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q3 - 0.2e1 * q2) + 0.2755000000e-2 * Dq1 ^ 2 * sin(q5 + 0.2e1 * q2 + 0.2e1 * q3) + 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + pi - q3) - 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + pi + q3) + 0.5220000000e-2 * Dq2 ^ 2 * cos(q5 + pi - q3) - 0.5220000000e-2 * Dq2 ^ 2 * cos(q5 + pi + q3) - 0.1015000000e-2 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2) + 0.1015000000e-2 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) + 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.5510000000e-2 * Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + pi / 0.2e1 + q4 + q2) - 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q4 - q2) + 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + pi / 0.2e1 - q4 + q2) + 0.5220000000e-2 * Dq1 * Dq2 * cos(q5 + 0.3e1 / 0.2e1 * pi + q4 - q2) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 - q4 + q3 + 0.2e1 * q2) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + 0.2e1 * pi + q4 - q3 - 0.2e1 * q2) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi + q4 - q3) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi - q4 + q3) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi - q4 - q3) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + pi + q4 + q3) - 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi + q4 - q3) - 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi - q4 + q3) - 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.5510000000e-2 * Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.1377500000e-2 * Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - q4 - 0.2e1 * q3 - 0.2e1 * q2) + 0.1377500000e-2 * Dq1 ^ 2 * sin(q5 + q4 + 0.2e1 * q3 + 0.2e1 * q2) - 0.1377500000e-2 * Dq1 ^ 2 * sin(q5 + 0.2e1 * pi - 0.2e1 * q2 - 0.2e1 * q3 + q4) + 0.1377500000e-2 * Dq1 ^ 2 * sin(q5 + 0.2e1 * q2 + 0.2e1 * q3 - q4) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.5075000000e-3 * Dq1 ^ 2 * cos(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + q4 + q3 + 0.2e1 * q2) - 0.1305000000e-2 * Dq1 ^ 2 * cos(q5 + 0.2e1 * pi - q4 - q3 - 0.2e1 * q2) - 0.1458000000e-2 * Dq6 * Dq4 * sin(q5 + pi) - 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi - q4 - q3) - 0.2610000000e-2 * Dq2 ^ 2 * cos(q5 + pi + q4 + q3) - 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.6800000000e-4 * Dq1 * Dq2 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq1 * Dq2 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.6800000000e-4 * Dq1 * Dq2 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) - 0.6800000000e-4 * Dq1 * Dq2 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq2 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq2 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + 0.6800000000e-4 * Dq1 * Dq3 * sin(-0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq3 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) - 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) - 0.6800000000e-4 * Dq1 * Dq3 * sin(0.2e1 * q4 + (2 * q5) + 0.3e1 / 0.2e1 * pi + q3 + q2) + 0.6800000000e-4 * Dq1 * Dq3 * sin(0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) - 0.6800000000e-4 * Dq1 * Dq3 * sin(-0.2e1 * q4 + (2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.1360000000e-3 * Dq1 * Dq3 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi - q4 + q3 + q2) + 0.2720000000e-3 * Dq1 * Dq4 * sin(q3 + q2 + 0.3e1 / 0.2e1 * pi + (2 * q5)) - 0.1360000000e-3 * Dq1 * Dq4 * sin(-q4 + 0.5e1 / 0.2e1 * pi + (2 * q5) - q3 - q2) + 0.1360000000e-3 * Dq1 * Dq4 * sin((2 * q5) + 0.3e1 / 0.2e1 * pi + q4 + q3 + q2) - 0.1360000000e-3 * Dq1 * Dq4 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi + q4 - q3 - q2) + 0.2720000000e-3 * Dq1 * Dq4 * sin((2 * q5) + 0.5e1 / 0.2e1 * pi - q3 - q2) + 0.7290000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.3645000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) + 0.7290000000e-3 * Dq1 * Dq6 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.1360000000e-3 * Dq2 * Dq3 * sin(0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) + 0.2720000000e-3 * Dq2 * Dq3 * sin(0.2e1 * pi + (2 * q5)) - 0.1360000000e-3 * Dq2 * Dq3 * sin(-0.2e1 * q4 + 0.2e1 * pi + (2 * q5)) + 0.2720000000e-3 * Dq2 * Dq4 * sin(q4 + 0.2e1 * pi + (2 * q5)) - 0.2720000000e-3 * Dq2 * Dq4 * sin((2 * q5) + 0.2e1 * pi - q4) + 0.7290000000e-3 * Dq2 * Dq6 * sin(q5 + pi + q4) - 0.7290000000e-3 * Dq2 * Dq6 * sin(q5 + pi - q4) + 0.2720000000e-3 * Dq3 * Dq4 * sin(q4 + 0.2e1 * pi + (2 * q5)) - 0.2720000000e-3 * Dq3 * Dq4 * sin((2 * q5) + 0.2e1 * pi - q4) + 0.7290000000e-3 * Dq3 * Dq6 * sin(q5 + pi + q4) - 0.7290000000e-3 * Dq3 * Dq6 * sin(q5 + pi - q4) - 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + q3 + 0.2e1 * q2) + 0.2610000000e-2 * Dq1 ^ 2 * cos(q5 + 0.2e1 * pi - q3 - 0.2e1 * q2) - 0.2204000000e-1 * sin(q5 + pi) * Dq2 * Dq3;
cdq6 = -0.7290000000e-3 * Dq4 * Dq3 * sin(q5 + pi - q4) + 0.7290000000e-3 * Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.7290000000e-3 * Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2) + 0.7290000000e-3 * Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.7290000000e-3 * Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2) - 0.7290000000e-3 * Dq5 * Dq2 * sin(q5 + pi + q4) + 0.7290000000e-3 * Dq5 * Dq2 * sin(q5 + pi - q4) - 0.7290000000e-3 * Dq5 * Dq3 * sin(q5 + pi + q4) + 0.7290000000e-3 * Dq5 * Dq3 * sin(q5 + pi - q4) - 0.7290000000e-3 * Dq5 * Dq1 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2) - 0.7290000000e-3 * Dq5 * Dq1 * sin(q5 + pi / 0.2e1 + q3 + q2) + 0.1458000000e-2 * Dq5 * sin(q5 + pi) * Dq4 + 0.3645000000e-3 * Dq5 * Dq1 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3645000000e-3 * Dq5 * Dq1 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) + 0.3645000000e-3 * Dq5 * Dq1 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.3645000000e-3 * Dq5 * Dq1 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3645000000e-3 * Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3645000000e-3 * Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.3645000000e-3 * Dq1 * Dq2 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.3645000000e-3 * Dq1 * Dq2 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3645000000e-3 * Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.3645000000e-3 * Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) - 0.3645000000e-3 * Dq1 * Dq3 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) - 0.3645000000e-3 * Dq1 * Dq3 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.3645000000e-3 * Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 - q4) - 0.3645000000e-3 * Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2 + q4) + 0.3645000000e-3 * Dq1 * Dq4 * sin(q5 + 0.3e1 / 0.2e1 * pi - q3 - q2 + q4) + 0.3645000000e-3 * Dq1 * Dq4 * sin(q5 + pi / 0.2e1 + q3 + q2 - q4) - 0.7290000000e-3 * Dq4 * Dq2 * sin(q5 + pi + q4) - 0.7290000000e-3 * Dq4 * Dq2 * sin(q5 + pi - q4) - 0.7290000000e-3 * Dq4 * Dq3 * sin(q5 + pi + q4);

%Setting up the matrices
M = [m11 m12 m13 m14 m15 m16;m21 m22 m23 m24 m25 m26;m31 m32 m33 m34 m35 m36;m41 m42 m43 m44 m45 m46;m51 m52 m53 m54 m55 m56;m61 m62 m63 m64 m65 m66];
G = [g1;g2;g3;g4;g5;g6];
CDq = [cdq1;cdq2;cdq3;cdq4;cdq5;cdq6];

%Computing the model
if gravityCompensation == 0
    DynSys = M\(-CDq-G+[u1;u2;u3;u4;u5;u6]);
else
    DynSys = M\(-CDq+[u1;u2;u3;u4;u5;u6]);
end

%Mapping to first-order system
dx1 = Dq1;
dx2 = DynSys(1);
dx3 = Dq2;
dx4 = DynSys(2);
dx5 = Dq3;
dx6 = DynSys(3);
dx7 = Dq4;
dx8 = DynSys(4);
dx9 = Dq5;
dx10 = DynSys(5);
dx11 = Dq6;
dx12 = DynSys(6);

%Sending to output port
dx = [dx1;dx2;dx3;dx4;dx5;dx6;dx7;dx8;dx9;dx10;dx11;dx12];
block.OutputPort(1).Data = dx;
